@@ -2,7 +2,7 @@ var NAVTREE =
 [
   [ "IMP.EMageFit", "index.html", [
     [ "IMP Mainpage", "../index.html", null ],
-    [ "All IMP Modules", "../md_doxygen_all.html", null ],
+    [ "All IMP Modules", "../allmod.html", null ],
     [ "EMageFit protocol", "emagefit_protocol.html", [
       [ "Input data", "emagefit_protocol.html#input", null ],
       [ "Producing models", "emagefit_protocol.html#models", [
@@ -14,21 +14,27 @@ var NAVTREE =
       ] ]
     ] ],
     [ "EMageFit scripts and tools", "emagefit_scripts.html", [
-      [ "Command line tools", "emagefit_scripts.html#tools", null ],
+      [ "Command line tools", "emagefit_scripts.html#tools", [
+        [ "emagefit: Run all steps of modeling", "emagefit_scripts.html#emagefit_bin", null ],
+        [ "emagefit_dock: Docking using the HEXDOCK program", "emagefit_scripts.html#emagefit_dock_bin", null ],
+        [ "emagefit_cluster: Performs clustering of the solutions stored in a database file.", "emagefit_scripts.html#emagefit_cluster_bin", null ],
+        [ "emagefit_score: Scores a model using EM images.", "emagefit_scripts.html#emagefit_score_bin", null ],
+        [ "convert_spider_to_jpg: Image conversion utility for EMageFit.", "emagefit_scripts.html#convert_spider_to_jpg_bin", null ]
+      ] ],
       [ "IMP.em2d Python package utilities", "emagefit_scripts.html#em2d_pkg", null ],
       [ "IMP.em2d.imp_general Python package utilities", "emagefit_scripts.html#em2d_gen_pkg", null ]
     ] ],
-    [ "Indexes", "../md_doxygen_argument_index.html", null ],
-    [ "Class Usage", "../md_doxygen_argument_index.html", null ],
-    [ "Class Examples", "../md_doxygen_class_example_index.html", null ],
-    [ "Class Factories", "../md_doxygen_factory_index.html", null ],
-    [ "Function Examples", "../md_doxygen_function_example_index.html", null ]
+    [ "Indexes", "../argument_index.html", null ],
+    [ "Class Usage", "../argument_index.html", null ],
+    [ "Class Examples", "../class_example_index.html", null ],
+    [ "Class Factories", "../factory_index.html", null ],
+    [ "Function Examples", "../function_example_index.html", null ]
   ] ]
 ];
 
 var NAVTREEINDEX =
 [
-"../index.html"
+"../allmod.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
