@@ -1,12 +1,12 @@
 var NAVTREEINDEX0 =
 {
+"../allmod.html":[1],
+"../argument_index.html":[4],
+"../argument_index.html":[5],
+"../class_example_index.html":[6],
+"../factory_index.html":[7],
+"../function_example_index.html":[8],
 "../index.html":[0],
-"../md_doxygen_all.html":[1],
-"../md_doxygen_argument_index.html":[4],
-"../md_doxygen_argument_index.html":[5],
-"../md_doxygen_class_example_index.html":[6],
-"../md_doxygen_factory_index.html":[7],
-"../md_doxygen_function_example_index.html":[8],
 "emagefit_protocol.html":[2],
 "emagefit_protocol.html#db":[2,1,4],
 "emagefit_protocol.html#docking":[2,1,0],
@@ -16,8 +16,13 @@ var NAVTREEINDEX0 =
 "emagefit_protocol.html#models":[2,1],
 "emagefit_protocol.html#montecarlo":[2,1,1],
 "emagefit_scripts.html":[3],
+"emagefit_scripts.html#convert_spider_to_jpg_bin":[3,0,4],
 "emagefit_scripts.html#em2d_gen_pkg":[3,2],
 "emagefit_scripts.html#em2d_pkg":[3,1],
+"emagefit_scripts.html#emagefit_bin":[3,0,0],
+"emagefit_scripts.html#emagefit_cluster_bin":[3,0,2],
+"emagefit_scripts.html#emagefit_dock_bin":[3,0,1],
+"emagefit_scripts.html#emagefit_score_bin":[3,0,3],
 "emagefit_scripts.html#tools":[3,0],
 "index.html":[],
 "pages.html":[]
