@@ -16,18 +16,13 @@ var SphereD_8h =
     [ "SphereKD", "SphereD_8h.html#ae8394f52404e0448ca99a1e8f5797883", null ],
     [ "SphereKDs", "SphereD_8h.html#a52c3f2b3b8a881dd475844dd5e4ef38f", null ],
     [ "get_area", "SphereD_8h.html#a6ada52de6426c614d94ba40f7f71df26", null ],
-    [ "get_bounding_box", "SphereD_8h.html#a47067f675abbea5ee3e4cad52da8b6f1", null ],
     [ "get_bounding_box", "SphereD_8h.html#ab71786f84ddb7835f6dd75bc61b1efda", null ],
     [ "get_distance", "SphereD_8h.html#a847f07074743af85946a6b46cd2a296f", null ],
     [ "get_interiors_intersect", "SphereD_8h.html#a9538f0814e3bdb8494ad2083acea5f20", null ],
     [ "get_power_distance", "SphereD_8h.html#a79e54ebe8fa9974a1401ba40be75d732", null ],
-    [ "get_sphere_d_geometry", "SphereD_8h.html#a247f001622da63d63ada98c50b29588d", null ],
-    [ "get_surface_area", "SphereD_8h.html#a9d5858e6431b1fbbf07ecda7336440b0", null ],
     [ "get_surface_area", "SphereD_8h.html#a59af2a64542f335ac33b2cc3b90f6681", null ],
     [ "get_unit_sphere_d", "SphereD_8h.html#a1ddf5b195507b476df0e26320f30cc9a", null ],
     [ "get_unit_sphere_kd", "SphereD_8h.html#a4834da35487ef0d191fbc1a9371724eb", null ],
     [ "get_vector_geometry", "SphereD_8h.html#a707b6892f5273351caf839871b84b04a", null ],
-    [ "get_volume", "SphereD_8h.html#a2b9e3c84f8b91881cd9b493400eaea60", null ],
-    [ "get_volume", "SphereD_8h.html#affca1f7420725f98cde80ad06a40364f", null ],
-    [ "set_sphere_d_geometry", "SphereD_8h.html#aeb646727111910951e2b8ceed2993b07", null ]
+    [ "get_volume", "SphereD_8h.html#affca1f7420725f98cde80ad06a40364f", null ]
 ];
\ No newline at end of file
