@@ -4,7 +4,5 @@ var atom__macros_8h =
     [ "IMP_FORCE_FIELD_PARAMETERS", "atom__macros_8h.html#aea73ded316726728c66938fa1ae5c7be", null ],
     [ "IMP_HIERARCHY_TYPE_INDEX", "atom__macros_8h.html#a13aefecdd05431ee855c372d9240aa92", null ],
     [ "IMP_MOL2_SELECTOR", "atom__macros_8h.html#a332d0754ad55c3371368af148340d24c", null ],
-    [ "IMP_PDB_SELECTOR", "atom__macros_8h.html#ab60b21e183b164c5d130115aa0796fb0", null ],
-    [ "IMP_RESIDUE_TYPE_INDEX", "atom__macros_8h.html#a057f80392f975d8d551d90df2ee94ada", null ],
-    [ "IMP_SIMULATOR", "atom__macros_8h.html#a7949839ede13df76a0ac1874bee5a66d", null ]
+    [ "IMP_RESIDUE_TYPE_INDEX", "atom__macros_8h.html#a057f80392f975d8d551d90df2ee94ada", null ]
 ];
\ No newline at end of file
