@@ -9,5 +9,10 @@ var classIMP_1_1algebra_1_1Cone3D =
     [ "get_height", "classIMP_1_1algebra_1_1Cone3D.html#a1bdf73555a879cbfc7c773f8c70f573e", null ],
     [ "get_radius", "classIMP_1_1algebra_1_1Cone3D.html#a87ce45f7f1ad3efd173fdb45d39d4000", null ],
     [ "get_tip", "classIMP_1_1algebra_1_1Cone3D.html#a5a1bb704f6a1ed8ccbc59082e53aa611", null ],
-    [ "show", "classIMP_1_1algebra_1_1Cone3D.html#a128c51787e2bae00fe10d48c4044e0ba", null ]
+    [ "show", "classIMP_1_1algebra_1_1Cone3D.html#a128c51787e2bae00fe10d48c4044e0ba", null ],
+    [ "get_bounding_box", "classIMP_1_1algebra_1_1Cone3D.html#a42215f5c82c6b41689887aee272d6f29", null ],
+    [ "get_cone_3d_geometry", "classIMP_1_1algebra_1_1Cone3D.html#a9408590e3b4ed9bea9901e0cc53f1039", null ],
+    [ "get_surface_area", "classIMP_1_1algebra_1_1Cone3D.html#a65a8552f8446684eba1acb5a97edd9c2", null ],
+    [ "get_volume", "classIMP_1_1algebra_1_1Cone3D.html#a024adad21c3b01de7558343ad0520532", null ],
+    [ "set_cone_3d_geometry", "classIMP_1_1algebra_1_1Cone3D.html#a8ef5b67cbfb8740ffc1efe1d2c28ab9e", null ]
 ];
\ No newline at end of file
