@@ -9,5 +9,10 @@ var classIMP_1_1algebra_1_1Ellipsoid3D =
     [ "get_reference_frame", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a64cdd46002ef8528e8583d5de98b749a", null ],
     [ "get_rotation", "classIMP_1_1algebra_1_1Ellipsoid3D.html#ab7b41bd7f224e14be6505a9871c2a078", null ],
     [ "get_transformation", "classIMP_1_1algebra_1_1Ellipsoid3D.html#af697d30feba4be5d1e03bb325696e577", null ],
-    [ "show", "classIMP_1_1algebra_1_1Ellipsoid3D.html#aa873c34dd7dfd9027d850d95680945fb", null ]
+    [ "show", "classIMP_1_1algebra_1_1Ellipsoid3D.html#aa873c34dd7dfd9027d850d95680945fb", null ],
+    [ "get_bounding_box", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a51e51989d370ac6d1f72605ea2b55659", null ],
+    [ "get_ellipsoid_3d_geometry", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a2fd68925f46292fc3f90454f7a34bded", null ],
+    [ "get_surface_area", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a5cea431932512ba0f6c5e54fd129deba", null ],
+    [ "get_volume", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a7a64fb811faa2d387a26960c723bb772", null ],
+    [ "set_ellipsoid_3d_geometry", "classIMP_1_1algebra_1_1Ellipsoid3D.html#a00d1a28d190859480cc3a8f1c01aef0e", null ]
 ];
\ No newline at end of file
