@@ -6,5 +6,7 @@ var classIMP_1_1algebra_1_1Segment3D =
     [ "get_length", "classIMP_1_1algebra_1_1Segment3D.html#a86f0d94dca2fe4e62e9883ed27458313", null ],
     [ "get_middle_point", "classIMP_1_1algebra_1_1Segment3D.html#a95866634d9b497b9388f5d2c0fd7060c", null ],
     [ "get_point", "classIMP_1_1algebra_1_1Segment3D.html#af03a6a66e92472aff506e205c22ebdca", null ],
-    [ "show", "classIMP_1_1algebra_1_1Segment3D.html#a25c359eee7fd1207a98a1a6eada8cc25", null ]
+    [ "show", "classIMP_1_1algebra_1_1Segment3D.html#a25c359eee7fd1207a98a1a6eada8cc25", null ],
+    [ "get_bounding_box", "classIMP_1_1algebra_1_1Segment3D.html#abd21d39499ca4acd3616d7a9355b90fd", null ],
+    [ "get_segment_3d_geometry", "classIMP_1_1algebra_1_1Segment3D.html#af5c43b376efc839be7570ffa3ee7825b", null ]
 ];
\ No newline at end of file
