@@ -1,7 +1,7 @@
 var classIMP_1_1atom_1_1LangevinThermostatOptimizerState =
 [
-    [ "LangevinThermostatOptimizerState", "classIMP_1_1atom_1_1LangevinThermostatOptimizerState.html#a70e61d56b3108935256bca1831a42c26", null ],
     [ "LangevinThermostatOptimizerState", "classIMP_1_1atom_1_1LangevinThermostatOptimizerState.html#ab4d3951090ea83b5875eda37543e58e3", null ],
+    [ "~LangevinThermostatOptimizerState", "classIMP_1_1atom_1_1LangevinThermostatOptimizerState.html#afe9aa506ef4e591b36af0ccfa92e8672", null ],
     [ "do_update", "classIMP_1_1atom_1_1LangevinThermostatOptimizerState.html#ae1a449f0e64a13d39372cab5ebd2a98f", null ],
     [ "get_gamma", "classIMP_1_1atom_1_1LangevinThermostatOptimizerState.html#aaba148c052c86a4faa1e06f63354cb9c", null ],
     [ "get_temperature", "classIMP_1_1atom_1_1LangevinThermostatOptimizerState.html#a9b49184483ef3ba967d1aaf4642b299a", null ],
