@@ -1,7 +1,7 @@
 var classIMP_1_1atom_1_1RemoveTranslationOptimizerState =
 [
-    [ "RemoveTranslationOptimizerState", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html#acf3e221a33bbf655d1813d196413e1a9", null ],
     [ "RemoveTranslationOptimizerState", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html#a208b5b2293fda1bfe89ba18170c33407", null ],
+    [ "~RemoveTranslationOptimizerState", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html#a6437e17c7506f0a748cbe7d491d1b6f1", null ],
     [ "do_update", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html#a2df2f686f349c301fdb9dd84e67b1bbe", null ],
     [ "get_type_name", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html#a38900b4e2b52884bef08385b879a70b3", null ],
     [ "get_version_info", "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html#a53131b4387b6c19d6cde4b22937d3461", null ],
