@@ -1,7 +1,7 @@
 var classIMP_1_1atom_1_1VelocityScalingOptimizerState =
 [
-    [ "VelocityScalingOptimizerState", "classIMP_1_1atom_1_1VelocityScalingOptimizerState.html#ae869bc8367bcc1f147eb9638e3e28d94", null ],
     [ "VelocityScalingOptimizerState", "classIMP_1_1atom_1_1VelocityScalingOptimizerState.html#a3ad919aac9c59b9a54789a3730acc073", null ],
+    [ "~VelocityScalingOptimizerState", "classIMP_1_1atom_1_1VelocityScalingOptimizerState.html#a6e8061fbaacd42643fe67d18b923b690", null ],
     [ "do_update", "classIMP_1_1atom_1_1VelocityScalingOptimizerState.html#a5dce1e17b5577219b0a26a4cfd041385", null ],
     [ "get_type_name", "classIMP_1_1atom_1_1VelocityScalingOptimizerState.html#aebc487a2f2105f2e04f89bb99bfd04ea", null ],
     [ "get_version_info", "classIMP_1_1atom_1_1VelocityScalingOptimizerState.html#a6ad1bef5cbd9f5973bef4915214f457e", null ],
