@@ -1,7 +1,7 @@
 var classIMP_1_1base_1_1Object =
 [
     [ "Object", "classIMP_1_1base_1_1Object.html#a984ca522763b56684601c96fe091fe6d", null ],
-    [ "Object", "classIMP_1_1base_1_1Object.html#a9c2049dab55c81cd66d7af81fc901708", null ],
+    [ "~Object", "classIMP_1_1base_1_1Object.html#a05e6a26c36c22e47ba048ba9dc3f8da4", null ],
     [ "clear_caches", "classIMP_1_1base_1_1Object.html#a5ec0fa3df8aa5878b916b6f9fd88c27f", null ],
     [ "do_destroy", "classIMP_1_1base_1_1Object.html#ae6e594095b0951cb98c3ae4e00c9ab4b", null ],
     [ "get_check_level", "classIMP_1_1base_1_1Object.html#a06c0e03c2227d204d45705c0bda00cc3", null ],
