@@ -4,6 +4,6 @@ var classIMP_1_1base_1_1TextInput =
     [ "TextInput", "classIMP_1_1base_1_1TextInput.html#a62613ee875fe018c92cfdd329e355787", null ],
     [ "TextInput", "classIMP_1_1base_1_1TextInput.html#a3b6d00b58f999aa3a3293b8c5733dcee", null ],
     [ "get_name", "classIMP_1_1base_1_1TextInput.html#af3b2f56e77ac68f837d8c6ba6cf26671", null ],
-    [ "IMP_SAFE_BOOL", "classIMP_1_1base_1_1TextInput.html#a476357dfa25b1071e74960c2bc747a0b", null ],
-    [ "IMP_SHOWABLE_INLINE", "classIMP_1_1base_1_1TextInput.html#a552e5720b3bf255a6562f717b84be9fe", null ]
+    [ "operator bool_type", "classIMP_1_1base_1_1TextInput.html#ae1dfc64de733ff81b24190cceb0735fb", null ],
+    [ "show", "classIMP_1_1base_1_1TextInput.html#a1ef176dd7aab31e95c02bab42a1129ec", null ]
 ];
\ No newline at end of file
