@@ -1,7 +1,7 @@
 var classIMP_1_1core_1_1ConjugateGradients =
 [
-    [ "ConjugateGradients", "classIMP_1_1core_1_1ConjugateGradients.html#af91eb57d32060bd8d29ae201377cfa12", null ],
     [ "ConjugateGradients", "classIMP_1_1core_1_1ConjugateGradients.html#a95ac65ba3a33dc06fb8616bea22eb7c6", null ],
+    [ "~ConjugateGradients", "classIMP_1_1core_1_1ConjugateGradients.html#a1518ccde82fe2d96c6fd3c5540238c1d", null ],
     [ "do_optimize", "classIMP_1_1core_1_1ConjugateGradients.html#af37cb032263f60a83173a5e58e71b2b7", null ],
     [ "get_type_name", "classIMP_1_1core_1_1ConjugateGradients.html#a7693f32e54c2089986a976eed2dc9551", null ],
     [ "get_version_info", "classIMP_1_1core_1_1ConjugateGradients.html#a64567a8c67b546e63d01caee003942f7", null ],
