@@ -1,6 +1,8 @@
 var classIMP_1_1core_1_1EdgePairGeometry =
 [
     [ "EdgePairGeometry", "classIMP_1_1core_1_1EdgePairGeometry.html#a4138958bdec520bb89edfbd1eda50d61", null ],
+    [ "~EdgePairGeometry", "classIMP_1_1core_1_1EdgePairGeometry.html#a450751e15de6f36d36a534d53cb77918", null ],
+    [ "get_components", "classIMP_1_1core_1_1EdgePairGeometry.html#a1513db4f075fbe3718d7e03954b8d4f8", null ],
     [ "get_type_name", "classIMP_1_1core_1_1EdgePairGeometry.html#a1c038f6e06582eadadc9a26249aa93af", null ],
     [ "get_version_info", "classIMP_1_1core_1_1EdgePairGeometry.html#a5773514bd4e75d772de1155dc578c628", null ]
 ];
\ No newline at end of file
