@@ -1,6 +1,8 @@
 var classIMP_1_1core_1_1EdgePairsGeometry =
 [
     [ "EdgePairsGeometry", "classIMP_1_1core_1_1EdgePairsGeometry.html#ab49030c10717d6f2966f7b5867650ce2", null ],
+    [ "~EdgePairsGeometry", "classIMP_1_1core_1_1EdgePairsGeometry.html#ad72077ceb776c2bc1f4a771954b25036", null ],
+    [ "get_components", "classIMP_1_1core_1_1EdgePairsGeometry.html#a8aac0548257177690fcd3557e8b7acf6", null ],
     [ "get_type_name", "classIMP_1_1core_1_1EdgePairsGeometry.html#a61338b6ec36915ca107cf551a2bd10a1", null ],
     [ "get_version_info", "classIMP_1_1core_1_1EdgePairsGeometry.html#a6d85d9533d4ff10898a78262103db6f7", null ]
 ];
\ No newline at end of file
