@@ -1,10 +1,13 @@
 var classIMP_1_1core_1_1FixedRefiner =
 [
     [ "FixedRefiner", "classIMP_1_1core_1_1FixedRefiner.html#ae8c5d691209cea73841cf91bc885bb84", null ],
+    [ "FixedRefiner", "classIMP_1_1core_1_1FixedRefiner.html#a33a061e763ac2eef136e7a358ace6c8e", null ],
     [ "~FixedRefiner", "classIMP_1_1core_1_1FixedRefiner.html#a6d93211f85cf484801d68913add209f3", null ],
     [ "do_get_inputs", "classIMP_1_1core_1_1FixedRefiner.html#a8ed1cccea8b16c6197c4c49111e12e7d", null ],
     [ "get_can_refine", "classIMP_1_1core_1_1FixedRefiner.html#ac33749ef6b6b7e6845b6e8a87a3590e7", null ],
-    [ "get_refined", "classIMP_1_1core_1_1FixedRefiner.html#a3baeaafa0aae93bfc15ef102f320aeee", null ],
+    [ "get_refined", "classIMP_1_1core_1_1FixedRefiner.html#a2f392daaed2b6ffb00cfd7e95bc7aacc", null ],
+    [ "get_refined_indexes", "classIMP_1_1core_1_1FixedRefiner.html#acfcca12623f9a956b362202add802112", null ],
+    [ "get_refined_indexes_by_ref", "classIMP_1_1core_1_1FixedRefiner.html#a1955d711ba5cb632dcc9e8036c6d6be9", null ],
     [ "get_type_name", "classIMP_1_1core_1_1FixedRefiner.html#ae1ca64b6cd4efc6f9032eab67852ff8a", null ],
     [ "get_version_info", "classIMP_1_1core_1_1FixedRefiner.html#a41bef8fa013955186a71c25b5289f4e5", null ]
 ];
\ No newline at end of file
