@@ -1,6 +1,8 @@
 var classIMP_1_1core_1_1RigidBodyFramesGeometry =
 [
     [ "RigidBodyFramesGeometry", "classIMP_1_1core_1_1RigidBodyFramesGeometry.html#a417f60df35bd50228cbbd78454167d7f", null ],
+    [ "~RigidBodyFramesGeometry", "classIMP_1_1core_1_1RigidBodyFramesGeometry.html#ab308486ad24517cbdcfa06cdc81d7557", null ],
+    [ "get_components", "classIMP_1_1core_1_1RigidBodyFramesGeometry.html#a98e2a7ab6cd285b46e267b5143b09be4", null ],
     [ "get_type_name", "classIMP_1_1core_1_1RigidBodyFramesGeometry.html#a1426898964f8b0daec306943721a7596", null ],
     [ "get_version_info", "classIMP_1_1core_1_1RigidBodyFramesGeometry.html#a2f9755a3c6e7649ef530ef1a310bd4cc", null ]
 ];
\ No newline at end of file
