@@ -1,7 +1,7 @@
 var classIMP_1_1core_1_1SteepestDescent =
 [
-    [ "SteepestDescent", "classIMP_1_1core_1_1SteepestDescent.html#a1364f52bce92c0b5df2a0d43f3e6c8f2", null ],
     [ "SteepestDescent", "classIMP_1_1core_1_1SteepestDescent.html#ad25c31cc5bea10243d5ebe250d30009f", null ],
+    [ "~SteepestDescent", "classIMP_1_1core_1_1SteepestDescent.html#a92d48357dd99a49460fadc29e7db44d6", null ],
     [ "do_optimize", "classIMP_1_1core_1_1SteepestDescent.html#a43b9129a323b37fabdadd2ac5bc429a9", null ],
     [ "get_type_name", "classIMP_1_1core_1_1SteepestDescent.html#a9471424ba84f815ba40c837b72bd7689", null ],
     [ "get_version_info", "classIMP_1_1core_1_1SteepestDescent.html#a96d51c2b125e21cf8d869e52c85b529e", null ],
