@@ -1,6 +1,8 @@
 var classIMP_1_1core_1_1XYZDerivativesGeometry =
 [
     [ "XYZDerivativesGeometry", "classIMP_1_1core_1_1XYZDerivativesGeometry.html#af6ebb040ac13ac913c8630dc8f660170", null ],
+    [ "~XYZDerivativesGeometry", "classIMP_1_1core_1_1XYZDerivativesGeometry.html#ac1b2865165c3232113f546facc536de7", null ],
+    [ "get_components", "classIMP_1_1core_1_1XYZDerivativesGeometry.html#adefe4fd8b89e15db44a53555643b85b0", null ],
     [ "get_type_name", "classIMP_1_1core_1_1XYZDerivativesGeometry.html#a7c4225372b4c19b4d3cb902a706ad88a", null ],
     [ "get_version_info", "classIMP_1_1core_1_1XYZDerivativesGeometry.html#a24f202752b87c6513a086b14729583c0", null ]
 ];
\ No newline at end of file
