@@ -1,9 +1,9 @@
 var classIMP_1_1domino_1_1IndexStates =
 [
+    [ "IndexStates", "classIMP_1_1domino_1_1IndexStates.html#a6830eb687329980d50db931ac69b0794", null ],
+    [ "~IndexStates", "classIMP_1_1domino_1_1IndexStates.html#a60372d2f1ad8160f825ec17e2945d99e", null ],
     [ "get_number_of_particle_states", "classIMP_1_1domino_1_1IndexStates.html#ad82bfc06bc998ce6a9642b7d8249ec8d", null ],
     [ "get_type_name", "classIMP_1_1domino_1_1IndexStates.html#ab50003d4e87c0f65a302d59d9e20f1b1", null ],
     [ "get_version_info", "classIMP_1_1domino_1_1IndexStates.html#a24efdf02a8f9a80e86da7f6749012ef6", null ],
-    [ "k_", "classIMP_1_1domino_1_1IndexStates.html#abc526e6407548eb1973ecc01436d7ca0", null ],
-    [ "load_particle_state", "classIMP_1_1domino_1_1IndexStates.html#a20fa5c5f87108fe06bd3b2dfdcede8df", null ],
-    [ "n_", "classIMP_1_1domino_1_1IndexStates.html#aceee10310bc5a84db1a5e852a364444e", null ]
+    [ "load_particle_state", "classIMP_1_1domino_1_1IndexStates.html#a20fa5c5f87108fe06bd3b2dfdcede8df", null ]
 ];
\ No newline at end of file
