@@ -1,8 +1,9 @@
 var classIMP_1_1example_1_1ExampleComplexRestraint =
 [
     [ "ExampleComplexRestraint", "classIMP_1_1example_1_1ExampleComplexRestraint.html#a2fdc2b737dd01072a9d87e90e3dee5b3", null ],
+    [ "~ExampleComplexRestraint", "classIMP_1_1example_1_1ExampleComplexRestraint.html#a12181894a197eed4d85cc34b6597e25b", null ],
     [ "do_get_inputs", "classIMP_1_1example_1_1ExampleComplexRestraint.html#a46c270beaf2aa3f5ca7bfeff5620853b", null ],
     [ "get_type_name", "classIMP_1_1example_1_1ExampleComplexRestraint.html#a77636ba879f4adbec4da36a9a88cf269", null ],
     [ "get_version_info", "classIMP_1_1example_1_1ExampleComplexRestraint.html#aa1ccb37ac27266d30afd7c61c6116279", null ],
-    [ "const", "classIMP_1_1example_1_1ExampleComplexRestraint.html#ac4337a9f76e67bc2d1532ec423424d42", null ]
+    [ "unprotected_evaluate", "classIMP_1_1example_1_1ExampleComplexRestraint.html#a1627fd71ef808be7ae8224cc13b4c300", null ]
 ];
\ No newline at end of file
