@@ -1,7 +1,7 @@
 var classIMP_1_1gsl_1_1ConjugateGradients =
 [
     [ "ConjugateGradients", "classIMP_1_1gsl_1_1ConjugateGradients.html#a450a66908b2144a086843df01db24e95", null ],
-    [ "ConjugateGradients", "classIMP_1_1gsl_1_1ConjugateGradients.html#ac631f938f16d93d714517ccb940ff3ec", null ],
+    [ "~ConjugateGradients", "classIMP_1_1gsl_1_1ConjugateGradients.html#a974de44a6275316a79588343a74e5c39", null ],
     [ "do_optimize", "classIMP_1_1gsl_1_1ConjugateGradients.html#a9700701875570869e47f0c88202be15d", null ],
     [ "get_type_name", "classIMP_1_1gsl_1_1ConjugateGradients.html#a8015939bc273c97af5cc876999458f46", null ],
     [ "get_version_info", "classIMP_1_1gsl_1_1ConjugateGradients.html#a6e515f8b6228ca6b083fb15ecfb312f3", null ],
