@@ -1,10 +1,11 @@
 var classIMP_1_1isd_1_1AmbiguousNOERestraint =
 [
     [ "AmbiguousNOERestraint", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#ac4ba7253a939b4a86978febfab4a7ce4", null ],
+    [ "~AmbiguousNOERestraint", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#af894fdb3ed40984cfff8f5deab3858da", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#adcd05142245b42f7e056a20bac594dfa", null ],
     [ "get_chi", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#a4a29edf75ec726784558d867bc73491f", null ],
     [ "get_probability", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#a168033efd8f972cfac52cbb39809ffd8", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#a5b129bb84c1036f573e3aaba10cb6d98", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#a0240689e2e260458f26ace0b690cd1d0", null ],
-    [ "const", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#a9cdabc35e412d2c6156353daf07b4d20", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html#a4fcdd62cde67e4da0f2eab0fcc1a8d52", null ]
 ];
\ No newline at end of file
