@@ -2,9 +2,10 @@ var classIMP_1_1isd_1_1AmbiguousRestraint =
 [
     [ "AmbiguousRestraint", "classIMP_1_1isd_1_1AmbiguousRestraint.html#a938caaca683e045e9bbf97269112a72b", null ],
     [ "AmbiguousRestraint", "classIMP_1_1isd_1_1AmbiguousRestraint.html#aa5643e9c855f323b7f2182a86bd7b44f", null ],
+    [ "~AmbiguousRestraint", "classIMP_1_1isd_1_1AmbiguousRestraint.html#a1a63a2b83511b0705789b0fa87710d2c", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1AmbiguousRestraint.html#a208326b55e9dfbb622a55ae1094574a5", null ],
     [ "get_probability", "classIMP_1_1isd_1_1AmbiguousRestraint.html#a5196effaea29a062ad20e62763f037dd", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1AmbiguousRestraint.html#a82eedb08367fa3187b1c6c23fe0e3e00", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1AmbiguousRestraint.html#ad14e6ab3d8dfc4e0f588debd54aaf0d1", null ],
-    [ "const", "classIMP_1_1isd_1_1AmbiguousRestraint.html#a4b1d02d79e7d941b39b91c9915417c69", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1AmbiguousRestraint.html#a3ae6263ec9e197dfc497dfeab62dc156", null ]
 ];
\ No newline at end of file
