@@ -1,6 +1,7 @@
 var classIMP_1_1isd_1_1MarginalNOERestraint =
 [
     [ "MarginalNOERestraint", "classIMP_1_1isd_1_1MarginalNOERestraint.html#a58a73a53500acfe28777ac061fb8f632", null ],
+    [ "~MarginalNOERestraint", "classIMP_1_1isd_1_1MarginalNOERestraint.html#aa5847dcf676d3fc3bf51da8c0b97037c", null ],
     [ "add_contribution", "classIMP_1_1isd_1_1MarginalNOERestraint.html#a5a1a7423c4a376322da5703edc19c567", null ],
     [ "add_contribution", "classIMP_1_1isd_1_1MarginalNOERestraint.html#a3e2610a86de5cc54d941d83118032d58", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1MarginalNOERestraint.html#a4beea6ce90f13ae1887630beebcfc1f4", null ],
@@ -10,5 +11,5 @@ var classIMP_1_1isd_1_1MarginalNOERestraint =
     [ "get_SS", "classIMP_1_1isd_1_1MarginalNOERestraint.html#a7951e4d6033eb8695a94a04d56850eff", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1MarginalNOERestraint.html#ac1f62cf9a19f25cc1cbf477f8ac0626c", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1MarginalNOERestraint.html#a313f7ee605525473724af19f09b3e26b", null ],
-    [ "const", "classIMP_1_1isd_1_1MarginalNOERestraint.html#ade0a99ce6bc1df09db5efc20f809a81e", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1MarginalNOERestraint.html#a7ec4bd1d3f89e990ef7b574ebe8aeac1", null ]
 ];
\ No newline at end of file
