@@ -1,9 +1,10 @@
 var classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint =
 [
     [ "vonMisesKappaConjugateRestraint", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#a331ae31255cc6226c53410f16ca69fdc", null ],
+    [ "~vonMisesKappaConjugateRestraint", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#afdf3217867f319ce4d8f0ec1e30463e8", null ],
     [ "do_get_inputs", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#ac3c9f0a248b6c38604b2b38f23445950", null ],
     [ "get_probability", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#a7680651db762330fb2b758fa715489e8", null ],
     [ "get_type_name", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#af2d99729d1a3d86d777305a5ae869d6a", null ],
     [ "get_version_info", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#ad0c57f53f2ccb3613771ac098ea6c2fd", null ],
-    [ "const", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#aa5d5068f3b471466e9291d36d9b1ad8f", null ]
+    [ "unprotected_evaluate", "classIMP_1_1isd_1_1vonMisesKappaConjugateRestraint.html#aa2a5f596aab6102ef9539094561bb9aa", null ]
 ];
\ No newline at end of file
