@@ -1,6 +1,7 @@
 var classIMP_1_1kernel_1_1Model =
 [
     [ "Model", "classIMP_1_1kernel_1_1Model.html#a20f1276ca2624012164672babdfd8bae", null ],
+    [ "~Model", "classIMP_1_1kernel_1_1Model.html#ae954ad57357f12d8babd37f7e269c819", null ],
     [ "add_attribute", "classIMP_1_1kernel_1_1Model.html#a130e5e6b09c4929becad3ed2c5e952ca", null ],
     [ "add_cache_attribute", "classIMP_1_1kernel_1_1Model.html#a667d50ea72b86b05a24c3f19f5ed0300", null ],
     [ "add_data", "classIMP_1_1kernel_1_1Model.html#af4020ed0f172180c96c3f1d142e11f76", null ],
@@ -23,7 +24,6 @@ var classIMP_1_1kernel_1_1Model =
     [ "get_number_of_particles", "classIMP_1_1kernel_1_1Model.html#a4190ae605b73420d40c02089722ffe54", null ],
     [ "get_number_of_restraints", "classIMP_1_1kernel_1_1Model.html#a884ad4c5a69f06d80a57e7fbf349d8fb", null ],
     [ "get_number_of_score_states", "classIMP_1_1kernel_1_1Model.html#ad6e1490e7f35950055c5f28f54534825", null ],
-    [ "get_optimized_particles", "classIMP_1_1kernel_1_1Model.html#a9d02e961a7a7f071219896126e59a5bb", null ],
     [ "get_particle", "classIMP_1_1kernel_1_1Model.html#afaae4848e02a7af53aba201c80fc947a", null ],
     [ "get_particle_indexes", "classIMP_1_1kernel_1_1Model.html#a077fd785f8ef3e8c29cc325ef65517f5", null ],
     [ "get_particle_name", "classIMP_1_1kernel_1_1Model.html#a4d4a8a6cd86102caf92c981e147104f0", null ],
