@@ -1,12 +1,14 @@
 var classIMP_1_1kernel_1_1Refiner =
 [
     [ "RefinedIterator", "classIMP_1_1kernel_1_1Refiner.html#a7d35e7cabf74659d072ea1e893bb3a64", null ],
-    [ "Refiner", "classIMP_1_1kernel_1_1Refiner.html#ac71e6041d089c03dfc498292d644f64c", null ],
+    [ "Refiner", "classIMP_1_1kernel_1_1Refiner.html#a48b1564b2118d1963b770180c230839a", null ],
     [ "get_can_refine", "classIMP_1_1kernel_1_1Refiner.html#a4defd8991c0d465c953f5d2b9a0e2af4", null ],
+    [ "get_is_by_ref_supported", "classIMP_1_1kernel_1_1Refiner.html#a62db4c7ccc1cf7a5d52ebd24cc46baba", null ],
     [ "get_number_of_refined", "classIMP_1_1kernel_1_1Refiner.html#a515635f617b363ae512c35e83f9dfca9", null ],
     [ "get_refined", "classIMP_1_1kernel_1_1Refiner.html#a24fcaeb8596469c3ed61ce48cb7eef90", null ],
     [ "get_refined", "classIMP_1_1kernel_1_1Refiner.html#afd5f1e512319f876a63c4982ffd4a62b", null ],
     [ "get_refined_indexes", "classIMP_1_1kernel_1_1Refiner.html#adf5ed7b069a84249fe87fdd355430d89", null ],
+    [ "get_refined_indexes_by_ref", "classIMP_1_1kernel_1_1Refiner.html#a6e2efdd8eb25bfcfd3d6a014d9e80bd5", null ],
     [ "refined_begin", "classIMP_1_1kernel_1_1Refiner.html#a76c480339c33da8136014a17f968ed3f", null ],
     [ "refined_end", "classIMP_1_1kernel_1_1Refiner.html#a2a88cd95e141e3ba6c943f61b0de6bd2", null ]
 ];
\ No newline at end of file
