@@ -3,5 +3,6 @@ var classIMP_1_1kernel_1_1SingletonContainerAdaptor =
     [ "SingletonContainerAdaptor", "classIMP_1_1kernel_1_1SingletonContainerAdaptor.html#a5a4b80125cc83e5d75431bc815240015", null ],
     [ "SingletonContainerAdaptor", "classIMP_1_1kernel_1_1SingletonContainerAdaptor.html#a09653008a1e8054a0a9b39aa5e9e60fc", null ],
     [ "SingletonContainerAdaptor", "classIMP_1_1kernel_1_1SingletonContainerAdaptor.html#ab2b8b48f408277bed3866ad7270c87ed", null ],
-    [ "SingletonContainerAdaptor", "classIMP_1_1kernel_1_1SingletonContainerAdaptor.html#a1dc7ab891388c9b7c0e357bef6d7b10b", null ]
+    [ "SingletonContainerAdaptor", "classIMP_1_1kernel_1_1SingletonContainerAdaptor.html#a05c8f02cd9bc025a34940c17b6704e56", null ],
+    [ "set_name_if_default", "classIMP_1_1kernel_1_1SingletonContainerAdaptor.html#a1b04df95334426c7243185971cfd2f2a", null ]
 ];
\ No newline at end of file
