@@ -3,5 +3,6 @@ var classIMP_1_1kernel_1_1TripletContainerAdaptor =
     [ "TripletContainerAdaptor", "classIMP_1_1kernel_1_1TripletContainerAdaptor.html#a6b6f530430a79abc644aed47e3bbd038", null ],
     [ "TripletContainerAdaptor", "classIMP_1_1kernel_1_1TripletContainerAdaptor.html#abaef4074f879e45a2057e002d14f177c", null ],
     [ "TripletContainerAdaptor", "classIMP_1_1kernel_1_1TripletContainerAdaptor.html#a15a0188df519aa5197e1863c7955596e", null ],
-    [ "TripletContainerAdaptor", "classIMP_1_1kernel_1_1TripletContainerAdaptor.html#af260480b8a62983c1ddee68d46cded00", null ]
+    [ "TripletContainerAdaptor", "classIMP_1_1kernel_1_1TripletContainerAdaptor.html#a3812055b4bb1c43c9e0f05880c215373", null ],
+    [ "set_name_if_default", "classIMP_1_1kernel_1_1TripletContainerAdaptor.html#ac14b11b325a954e22887c5a19e40ece8", null ]
 ];
\ No newline at end of file
