@@ -7,7 +7,7 @@ var classIMP_1_1pmi_1_1Uncertainty =
     [ "get_is_setup", "classIMP_1_1pmi_1_1Uncertainty.html#a91990017cd3dac707c5229bbfbf6b4a9", null ],
     [ "get_uncertainty", "classIMP_1_1pmi_1_1Uncertainty.html#ae7dae1d629f207c29c570ffdfd7b06c1", null ],
     [ "get_uncertainty_key", "classIMP_1_1pmi_1_1Uncertainty.html#a7b0f0f5305ad5cd33c61aed9d6609e78", null ],
-    [ "set_Uncertainty", "classIMP_1_1pmi_1_1Uncertainty.html#a8a0655bc1192eb3373bde160a98f95cf", null ],
+    [ "set_uncertainty", "classIMP_1_1pmi_1_1Uncertainty.html#a21ccda1492e13207b73ec855865f45a5", null ],
     [ "setup_particle", "classIMP_1_1pmi_1_1Uncertainty.html#ada189b2935cf9659fec64ca96e566b77", null ],
     [ "setup_particle", "classIMP_1_1pmi_1_1Uncertainty.html#ab9139b4882cf1867b9759f068512e843", null ],
     [ "show", "classIMP_1_1pmi_1_1Uncertainty.html#ade27bab85902a50cb2742b8ac4404048", null ]
