@@ -1,7 +1,7 @@
 var classIMP_1_1rmf_1_1SaveOptimizerState =
 [
     [ "SaveOptimizerState", "classIMP_1_1rmf_1_1SaveOptimizerState.html#a33fb072e426905196b216c175d8046cc", null ],
-    [ "SaveOptimizerState", "classIMP_1_1rmf_1_1SaveOptimizerState.html#a22d95047455a119a65c53e6c4d1e326a", null ],
+    [ "~SaveOptimizerState", "classIMP_1_1rmf_1_1SaveOptimizerState.html#a4c94527dc70f4f76fabe330fcfba8172", null ],
     [ "do_update", "classIMP_1_1rmf_1_1SaveOptimizerState.html#a590a607ee0eda88b40827827c9ebc679", null ],
     [ "get_type_name", "classIMP_1_1rmf_1_1SaveOptimizerState.html#a5d9352382c753791edb93021ce683f7c", null ],
     [ "get_version_info", "classIMP_1_1rmf_1_1SaveOptimizerState.html#afd68c21536f429bb19605464743f8996", null ],
