@@ -2,19 +2,33 @@ var NAVTREE =
 [
   [ "IMP.integrative_docking", "index.html", [
     [ "IMP Mainpage", "../index.html", null ],
-    [ "All IMP Modules", "../md_doxygen_all.html", null ],
-    [ "Integrative docking utility programs", "idock_progs.html", null ],
-    [ "Indexes", "../md_doxygen_argument_index.html", null ],
-    [ "Class Usage", "../md_doxygen_argument_index.html", null ],
-    [ "Class Examples", "../md_doxygen_class_example_index.html", null ],
-    [ "Class Factories", "../md_doxygen_factory_index.html", null ],
-    [ "Function Examples", "../md_doxygen_function_example_index.html", null ]
+    [ "All IMP Modules", "../allmod.html", null ],
+    [ "Integrative docking utility programs", "idock_progs.html", [
+      [ "saxs_score", "idock_progs.html#saxs_score_bin", null ],
+      [ "em2d_score", "idock_progs.html#em2d_score_bin", null ],
+      [ "em3d_score", "idock_progs.html#em3d_score_bin", null ],
+      [ "nmr_rtc_score", "idock_progs.html#nmr_rtc_score_bin", null ],
+      [ "cross_links_score", "idock_progs.html#cross_links_score_bin", null ],
+      [ "combine_scores", "idock_progs.html#combine_scores_bin", null ],
+      [ "recompute_zscore", "idock_progs.html#recompute_zscore_bin", null ],
+      [ "em3d_single_score", "idock_progs.html#em3d_single_score_bin", null ],
+      [ "em2d_single_score", "idock_progs.html#em2d_single_score_bin", null ],
+      [ "soap_score", "idock_progs.html#soap_score_bin", null ],
+      [ "cross_links_single_score", "idock_progs.html#cross_links_single_score_bin", null ],
+      [ "interface_cross_links", "idock_progs.html#interface_cross_links_bin", null ],
+      [ "interface_rtc", "idock_progs.html#interface_rtc_bin", null ]
+    ] ],
+    [ "Indexes", "../argument_index.html", null ],
+    [ "Class Usage", "../argument_index.html", null ],
+    [ "Class Examples", "../class_example_index.html", null ],
+    [ "Class Factories", "../factory_index.html", null ],
+    [ "Function Examples", "../function_example_index.html", null ]
   ] ]
 ];
 
 var NAVTREEINDEX =
 [
-"../index.html"
+"../allmod.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
