@@ -2,5 +2,6 @@ var metric__clustering_8h =
 [
     [ "create_centrality_clustering", "metric__clustering_8h.html#a033ac0d9e680dc724a782c219391dc5c", null ],
     [ "create_connectivity_clustering", "metric__clustering_8h.html#a7fa3185254b0cf61b8baa2b04e3461c6", null ],
-    [ "create_diameter_clustering", "metric__clustering_8h.html#ae34d7252a499c1f7a6948fa5283f88a6", null ]
+    [ "create_diameter_clustering", "metric__clustering_8h.html#ae34d7252a499c1f7a6948fa5283f88a6", null ],
+    [ "create_gromos_clustering", "metric__clustering_8h.html#a739c887af40a30b27d360f052f3d001b", null ]
 ];
\ No newline at end of file
