@@ -2,18 +2,18 @@ var NAVTREE =
 [
   [ "IMP.multifit_tools", "index.html", [
     [ "IMP Mainpage", "../index.html", null ],
-    [ "All IMP Modules", "../md_doxygen_all.html", null ],
-    [ "Indexes", "../md_doxygen_argument_index.html", null ],
-    [ "Class Usage", "../md_doxygen_argument_index.html", null ],
-    [ "Class Examples", "../md_doxygen_class_example_index.html", null ],
-    [ "Class Factories", "../md_doxygen_factory_index.html", null ],
-    [ "Function Examples", "../md_doxygen_function_example_index.html", null ]
+    [ "All IMP Modules", "../allmod.html", null ],
+    [ "Indexes", "../argument_index.html", null ],
+    [ "Class Usage", "../argument_index.html", null ],
+    [ "Class Examples", "../class_example_index.html", null ],
+    [ "Class Factories", "../factory_index.html", null ],
+    [ "Function Examples", "../function_example_index.html", null ]
   ] ]
 ];
 
 var NAVTREEINDEX =
 [
-"../index.html"
+"../allmod.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
