@@ -4,11 +4,13 @@ var namespaceIMP_1_1base =
     [ "AddFloatFlag", "structIMP_1_1base_1_1AddFloatFlag.html", "structIMP_1_1base_1_1AddFloatFlag" ],
     [ "AddIntFlag", "structIMP_1_1base_1_1AddIntFlag.html", "structIMP_1_1base_1_1AddIntFlag" ],
     [ "AddStringFlag", "structIMP_1_1base_1_1AddStringFlag.html", "structIMP_1_1base_1_1AddStringFlag" ],
+    [ "AdvancedFlag", "classIMP_1_1base_1_1AdvancedFlag.html", "classIMP_1_1base_1_1AdvancedFlag" ],
     [ "Array", "classIMP_1_1base_1_1Array.html", "classIMP_1_1base_1_1Array" ],
     [ "ConstVector", "classIMP_1_1base_1_1ConstVector.html", "classIMP_1_1base_1_1ConstVector" ],
     [ "CreateLogContext", "classIMP_1_1base_1_1CreateLogContext.html", "classIMP_1_1base_1_1CreateLogContext" ],
     [ "EventException", "classIMP_1_1base_1_1EventException.html", "classIMP_1_1base_1_1EventException" ],
     [ "Exception", "classIMP_1_1base_1_1Exception.html", "classIMP_1_1base_1_1Exception" ],
+    [ "Flag", "classIMP_1_1base_1_1Flag.html", "classIMP_1_1base_1_1Flag" ],
     [ "Index", "classIMP_1_1base_1_1Index.html", "classIMP_1_1base_1_1Index" ],
     [ "IndexException", "classIMP_1_1base_1_1IndexException.html", "classIMP_1_1base_1_1IndexException" ],
     [ "IndexVector", "classIMP_1_1base_1_1IndexVector.html", "classIMP_1_1base_1_1IndexVector" ],
@@ -21,7 +23,6 @@ var namespaceIMP_1_1base =
     [ "ModelException", "classIMP_1_1base_1_1ModelException.html", "classIMP_1_1base_1_1ModelException" ],
     [ "NonCopyable", "classIMP_1_1base_1_1NonCopyable.html", "classIMP_1_1base_1_1NonCopyable" ],
     [ "Object", "classIMP_1_1base_1_1Object.html", "classIMP_1_1base_1_1Object" ],
-    [ "OwnerPointer", "structIMP_1_1base_1_1OwnerPointer.html", "structIMP_1_1base_1_1OwnerPointer" ],
     [ "piecewise_linear_distribution", "classIMP_1_1base_1_1piecewise__linear__distribution.html", "classIMP_1_1base_1_1piecewise__linear__distribution" ],
     [ "Pointer", "structIMP_1_1base_1_1Pointer.html", "structIMP_1_1base_1_1Pointer" ],
     [ "PointerMember", "structIMP_1_1base_1_1PointerMember.html", "structIMP_1_1base_1_1PointerMember" ],
