@@ -12,13 +12,17 @@ var namespaceIMP_1_1em2d =
     ] ],
     [ "restraints", "namespaceIMP_1_1em2d_1_1restraints.html", null ],
     [ "solutions_io", "namespaceIMP_1_1em2d_1_1solutions__io.html", "namespaceIMP_1_1em2d_1_1solutions__io" ],
+    [ "AverageDistanceLinkage", "classIMP_1_1em2d_1_1AverageDistanceLinkage.html", "classIMP_1_1em2d_1_1AverageDistanceLinkage" ],
     [ "CenteredMat", "classIMP_1_1em2d_1_1CenteredMat.html", "classIMP_1_1em2d_1_1CenteredMat" ],
     [ "ChiSquaredScore", "classIMP_1_1em2d_1_1ChiSquaredScore.html", "classIMP_1_1em2d_1_1ChiSquaredScore" ],
+    [ "ClusterSet", "classIMP_1_1em2d_1_1ClusterSet.html", "classIMP_1_1em2d_1_1ClusterSet" ],
     [ "CollisionCrossSection", "classIMP_1_1em2d_1_1CollisionCrossSection.html", "classIMP_1_1em2d_1_1CollisionCrossSection" ],
+    [ "CompleteLinkage", "classIMP_1_1em2d_1_1CompleteLinkage.html", "classIMP_1_1em2d_1_1CompleteLinkage" ],
     [ "DistanceFilter", "classIMP_1_1em2d_1_1DistanceFilter.html", "classIMP_1_1em2d_1_1DistanceFilter" ],
     [ "DistanceFilterTable", "classIMP_1_1em2d_1_1DistanceFilterTable.html", "classIMP_1_1em2d_1_1DistanceFilterTable" ],
     [ "DummyRestraint", "classIMP_1_1em2d_1_1DummyRestraint.html", "classIMP_1_1em2d_1_1DummyRestraint" ],
     [ "Em2DRestraint", "classIMP_1_1em2d_1_1Em2DRestraint.html", "classIMP_1_1em2d_1_1Em2DRestraint" ],
+    [ "Em2DRestraintParameters", "classIMP_1_1em2d_1_1Em2DRestraintParameters.html", "classIMP_1_1em2d_1_1Em2DRestraintParameters" ],
     [ "EM2DScore", "classIMP_1_1em2d_1_1EM2DScore.html", "classIMP_1_1em2d_1_1EM2DScore" ],
     [ "Fine2DRegistrationRestraint", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint.html", "classIMP_1_1em2d_1_1Fine2DRegistrationRestraint" ],
     [ "GridStates", "classIMP_1_1em2d_1_1GridStates.html", "classIMP_1_1em2d_1_1GridStates" ],
@@ -26,12 +30,14 @@ var namespaceIMP_1_1em2d =
     [ "HasLowerScore", "classIMP_1_1em2d_1_1HasLowerScore.html", "classIMP_1_1em2d_1_1HasLowerScore" ],
     [ "Image", "classIMP_1_1em2d_1_1Image.html", "classIMP_1_1em2d_1_1Image" ],
     [ "ImageReaderWriter", "classIMP_1_1em2d_1_1ImageReaderWriter.html", "classIMP_1_1em2d_1_1ImageReaderWriter" ],
+    [ "IntsOrder", "classIMP_1_1em2d_1_1IntsOrder.html", "classIMP_1_1em2d_1_1IntsOrder" ],
     [ "JPGImageReaderWriter", "classIMP_1_1em2d_1_1JPGImageReaderWriter.html", "classIMP_1_1em2d_1_1JPGImageReaderWriter" ],
     [ "LessPairBySecond", "classIMP_1_1em2d_1_1LessPairBySecond.html", "classIMP_1_1em2d_1_1LessPairBySecond" ],
     [ "MasksManager", "classIMP_1_1em2d_1_1MasksManager.html", "classIMP_1_1em2d_1_1MasksManager" ],
     [ "MatchTemplateResult", "classIMP_1_1em2d_1_1MatchTemplateResult.html", "classIMP_1_1em2d_1_1MatchTemplateResult" ],
     [ "MeanAbsoluteDifference", "classIMP_1_1em2d_1_1MeanAbsoluteDifference.html", "classIMP_1_1em2d_1_1MeanAbsoluteDifference" ],
     [ "ParticlesDummyRestraint", "classIMP_1_1em2d_1_1ParticlesDummyRestraint.html", "classIMP_1_1em2d_1_1ParticlesDummyRestraint" ],
+    [ "PCAFitRestraint", "classIMP_1_1em2d_1_1PCAFitRestraint.html", "classIMP_1_1em2d_1_1PCAFitRestraint" ],
     [ "PolarResamplingParameters", "classIMP_1_1em2d_1_1PolarResamplingParameters.html", "classIMP_1_1em2d_1_1PolarResamplingParameters" ],
     [ "ProjectingOptions", "classIMP_1_1em2d_1_1ProjectingOptions.html", "classIMP_1_1em2d_1_1ProjectingOptions" ],
     [ "ProjectingParameters", "classIMP_1_1em2d_1_1ProjectingParameters.html", "classIMP_1_1em2d_1_1ProjectingParameters" ],
@@ -45,6 +51,7 @@ var namespaceIMP_1_1em2d =
     [ "RigidBodiesImageFitRestraint", "classIMP_1_1em2d_1_1RigidBodiesImageFitRestraint.html", "classIMP_1_1em2d_1_1RigidBodiesImageFitRestraint" ],
     [ "ScoreFunction", "classIMP_1_1em2d_1_1ScoreFunction.html", "classIMP_1_1em2d_1_1ScoreFunction" ],
     [ "SegmentationParameters", "classIMP_1_1em2d_1_1SegmentationParameters.html", "classIMP_1_1em2d_1_1SegmentationParameters" ],
+    [ "SingleLinkage", "classIMP_1_1em2d_1_1SingleLinkage.html", "classIMP_1_1em2d_1_1SingleLinkage" ],
     [ "SpiderImageReaderWriter", "classIMP_1_1em2d_1_1SpiderImageReaderWriter.html", "classIMP_1_1em2d_1_1SpiderImageReaderWriter" ],
     [ "TIFFImageReaderWriter", "classIMP_1_1em2d_1_1TIFFImageReaderWriter.html", "classIMP_1_1em2d_1_1TIFFImageReaderWriter" ]
 ];
\ No newline at end of file
