@@ -8,6 +8,7 @@ var namespaceIMP_1_1isd =
       [ "LogHolder", "classIMP_1_1isd_1_1demux__trajs_1_1LogHolder.html", "classIMP_1_1isd_1_1demux__trajs_1_1LogHolder" ]
     ] ],
     [ "Entry", "namespaceIMP_1_1isd_1_1Entry.html", null ],
+    [ "gmm_tools", "namespaceIMP_1_1isd_1_1gmm__tools.html", null ],
     [ "History", "namespaceIMP_1_1isd_1_1History.html", "namespaceIMP_1_1isd_1_1History" ],
     [ "shared_functions", null, [
       [ "sfo_common", "classIMP_1_1isd_1_1shared__functions_1_1sfo__common.html", "classIMP_1_1isd_1_1shared__functions_1_1sfo__common" ]
@@ -23,6 +24,7 @@ var namespaceIMP_1_1isd =
     [ "utils", "namespaceIMP_1_1isd_1_1utils.html", "namespaceIMP_1_1isd_1_1utils" ],
     [ "AmbiguousNOERestraint", "classIMP_1_1isd_1_1AmbiguousNOERestraint.html", "classIMP_1_1isd_1_1AmbiguousNOERestraint" ],
     [ "AmbiguousRestraint", "classIMP_1_1isd_1_1AmbiguousRestraint.html", "classIMP_1_1isd_1_1AmbiguousRestraint" ],
+    [ "AtomicCrossLinkMSRestraint", "classIMP_1_1isd_1_1AtomicCrossLinkMSRestraint.html", "classIMP_1_1isd_1_1AtomicCrossLinkMSRestraint" ],
     [ "BivariateFunction", "classIMP_1_1isd_1_1BivariateFunction.html", "classIMP_1_1isd_1_1BivariateFunction" ],
     [ "Covariance1DFunction", "classIMP_1_1isd_1_1Covariance1DFunction.html", "classIMP_1_1isd_1_1Covariance1DFunction" ],
     [ "CrossLinkData", "classIMP_1_1isd_1_1CrossLinkData.html", "classIMP_1_1isd_1_1CrossLinkData" ],
@@ -32,6 +34,7 @@ var namespaceIMP_1_1isd =
     [ "FNormal", "classIMP_1_1isd_1_1FNormal.html", "classIMP_1_1isd_1_1FNormal" ],
     [ "FretData", "classIMP_1_1isd_1_1FretData.html", "classIMP_1_1isd_1_1FretData" ],
     [ "FretRestraint", "classIMP_1_1isd_1_1FretRestraint.html", "classIMP_1_1isd_1_1FretRestraint" ],
+    [ "GaussianEMRestraint", "classIMP_1_1isd_1_1GaussianEMRestraint.html", "classIMP_1_1isd_1_1GaussianEMRestraint" ],
     [ "GaussianProcessInterpolation", "classIMP_1_1isd_1_1GaussianProcessInterpolation.html", "classIMP_1_1isd_1_1GaussianProcessInterpolation" ],
     [ "GaussianProcessInterpolationRestraint", "classIMP_1_1isd_1_1GaussianProcessInterpolationRestraint.html", "classIMP_1_1isd_1_1GaussianProcessInterpolationRestraint" ],
     [ "GaussianRestraint", "classIMP_1_1isd_1_1GaussianRestraint.html", "classIMP_1_1isd_1_1GaussianRestraint" ],
