@@ -10,10 +10,6 @@ var namespaceIMP_1_1kernel =
     [ "DerivativeAccumulator", "classIMP_1_1kernel_1_1DerivativeAccumulator.html", "classIMP_1_1kernel_1_1DerivativeAccumulator" ],
     [ "EvaluationState", "structIMP_1_1kernel_1_1EvaluationState.html", "structIMP_1_1kernel_1_1EvaluationState" ],
     [ "FloatIndex", "structIMP_1_1kernel_1_1FloatIndex.html", "structIMP_1_1kernel_1_1FloatIndex" ],
-    [ "GenericScopedRemoveRestraint", "classIMP_1_1kernel_1_1GenericScopedRemoveRestraint.html", "classIMP_1_1kernel_1_1GenericScopedRemoveRestraint" ],
-    [ "GenericScopedRemoveScoreState", "classIMP_1_1kernel_1_1GenericScopedRemoveScoreState.html", "classIMP_1_1kernel_1_1GenericScopedRemoveScoreState" ],
-    [ "GenericScopedRestraint", "classIMP_1_1kernel_1_1GenericScopedRestraint.html", "classIMP_1_1kernel_1_1GenericScopedRestraint" ],
-    [ "GenericScopedScoreState", "classIMP_1_1kernel_1_1GenericScopedScoreState.html", "classIMP_1_1kernel_1_1GenericScopedScoreState" ],
     [ "Key", "classIMP_1_1kernel_1_1Key.html", "classIMP_1_1kernel_1_1Key" ],
     [ "Model", "classIMP_1_1kernel_1_1Model.html", "classIMP_1_1kernel_1_1Model" ],
     [ "ModelObject", "classIMP_1_1kernel_1_1ModelObject.html", "classIMP_1_1kernel_1_1ModelObject" ],
