@@ -176,6 +176,7 @@ var NAVTREE =
     ] ],
     [ "Publications", "publications.html", null ],
     [ "ChangeLog", "changelog.html", [
+      [ "For IMP 2.3.1", "changelog.html#changelog_2_3_1", null ],
       [ "For IMP 2.3.0", "changelog.html#changelog_2_3_0", null ],
       [ "For IMP 2.2.1", "changelog.html#changelog_2_2_1", null ],
       [ "For IMP 2.2.0", "changelog.html#changelog_2_2_0", null ],
@@ -228,58 +229,59 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 ".html",
-"CoulombPairScore_8h.html#a04218618b57f4ef105c734035c6a0f8b",
-"FFToperations_8h_source.html",
-"MinimumSingletonScore_8h.html#ac7a69a565f80c4689894387fb56c6600",
-"Representation_8h.html#a61dee2f147ce893b5d15f778f480399a",
-"SphereDistancePairScore_8h.html#a8268650cc29af14ce188da04e696536a",
-"Writer_8h.html#a6820324d2c955570dd63b82da98c86f2",
-"atom_2multiresolution_8py_source.html",
-"classIMP_1_1algebra_1_1DenseGridStorageD.html#a2db7b83ea46076f7fc8f1952535ccb46",
-"classIMP_1_1algebra_1_1Rotation3D.html#a65b6637966fb8c03f68f0154476dd634",
-"classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html#a4f54ff8eff2631ef67314e3a14475023",
-"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#ad610c4fa66857daaad66e9ab60c548c1",
-"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#aa15d0d9450dc2754e6482ed960d0c03f",
-"classIMP_1_1atom_1_1Representation.html#a671c63f48506751b5b51d3b76f85f4f3",
-"classIMP_1_1base_1_1CreateLogContext.html#a11dfac8a833d9ade6f417ba109118683",
-"classIMP_1_1container_1_1AllPairContainer.html",
-"classIMP_1_1container_1_1InContainerSingletonFilter.html#af780e2aee9aed1b849285603f61edd8b",
-"classIMP_1_1container_1_1QuadsConstraint.html#aae8c74b15bc4e074dc28d54e5dd22b7e",
-"classIMP_1_1core_1_1ClosePairsFinder.html#a260df5bb0b19f08f6a946fed32d9fd44",
-"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#aafdb5271265f58bdc71b60dacc22387b",
-"classIMP_1_1core_1_1MCCGSampler.html#a3ad5f593362818b3b8115f36e9bc1111",
-"classIMP_1_1core_1_1PairRestraint.html#afda31f4d04282c351df80caa655f4568",
-"classIMP_1_1core_1_1SphereDistancePairScore.html#af35d96e28844898402854dbb38d58102",
-"classIMP_1_1core_1_1XYZRGeometry.html",
-"classIMP_1_1display_1_1SurfaceMeshGeometry.html#a8f91ce225f18c560636d9d0557c5d357",
-"classIMP_1_1domino_1_1ListSubsetFilterTable.html#a9d3812f6d072fb1881a6577001164e1e",
-"classIMP_1_1em2d_1_1AverageDistanceLinkage.html#ad482ade917710e728848f4bc505b0f96",
-"classIMP_1_1em2d_1_1LessPairBySecond.html#a986b458d6b857a5c6ed4f55ab3a7126c",
-"classIMP_1_1em2d_1_1RelativePositionMover.html#a3ca8e3a56238e55cc25c94deb52a6210",
-"classIMP_1_1em_1_1DensityHeader.html#adfc8ab196e2516e5f182a261bbb43555",
-"classIMP_1_1em_1_1ImageHeader.html#aadd0126d38b91508f2259df1720c0387",
-"classIMP_1_1example_1_1ExampleTemplateClassD.html#a86ede654e64072869b8c25f23bfde3d6",
-"classIMP_1_1isd_1_1GaussianProcessInterpolationRestraint.html#a1bf84d2d5ff3eee0f3e4ed1516e36ae1",
-"classIMP_1_1isd_1_1Nuisance.html#a8b30adf98eba1ab174ad30c8f28bff08",
-"classIMP_1_1kernel_1_1AttributeOptimizer.html#aa393fac0cc48612115d0c1acc355a8fd",
-"classIMP_1_1kernel_1_1ParticleAdaptor.html#ad1622f002cda2d25b9dcbdf7da5d93db",
-"classIMP_1_1kernel_1_1SingletonContainerAdaptor.html#ab2b8b48f408277bed3866ad7270c87ed",
-"classIMP_1_1kinematics_1_1RevoluteJoint.html#ab16ab27fe631f6712ab0030d601b0e07",
-"classIMP_1_1multifit_1_1ComponentHeader.html#a8faadd8b23c04c081b8b48d46a99018a",
-"classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html#a312efc0ebb0f02c4b04894dce3398a7c",
-"classIMP_1_1pmi_1_1Symmetric.html#ad525fd60aa8680a457e23397c2476eb1",
-"classIMP_1_1saxs_1_1Profile.html#aad86fc9975dd25aadd81a698410918ac",
-"classIMP_1_1statistics_1_1ParticleEmbedding.html#af7ec8e319c0513e96e837e887914ec50",
-"core_2incremental_mc_8py-example.html",
-"element_8h.html#a611e6343bbcfccda53cc687bd1b23845a554f00a8a08a3df6736927235dae6b07",
-"flags_8h.html",
-"image__processing_8h.html#a006185fb87d9ea8b0cded91418a529ed",
-"kernel_2base__types_8h.html#a1aab4310d217f84cd7926039e222cfa0",
-"kernel_2macros_8h_source.html",
-"namespaceIMP_1_1em2d_1_1buildxlinks.html",
-"pepdock_8h_source.html",
-"set__map__macros_8h.html#a09b1ac40792f226deb85bd87e5e81a16",
-"subset__filters_8h.html#ad64ef28d74a87ec5a6c3cc0586b8b5a5"
+"Cosine_8h_source.html",
+"FFToperations_8h.html#ade457bcb204e0cdbc3f37c62735a95c3",
+"MinimumSingletonRestraint_8h.html",
+"Representation_8h.html#a0413486542eba96a7d75081dff43a096",
+"SphereD_8h_source.html",
+"Writer_8h.html#a144d1cadcee25ee07afe7e531251f09b",
+"atom_2edit_molecular_hierarchy_8py-example.html",
+"classIMP_1_1algebra_1_1DefaultEmbeddingD.html#aa939cc38c61633c05ba8f512671c9922",
+"classIMP_1_1algebra_1_1Rotation3D.html#a245bbd42a3c675e79a9ad216d7b63be4",
+"classIMP_1_1atom_1_1BackbonePDBSelector.html#aac44df734c94bf99290149aa244ce0e7",
+"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aa4f8390a6d5efc7d3a94689490a32808",
+"classIMP_1_1atom_1_1ForceFieldParameters.html#afc93d5738add08b79a76395b1afb861b",
+"classIMP_1_1atom_1_1Representation.html#a3086e40c0518364751d0fe8098b07335",
+"classIMP_1_1base_1_1ConstVector.html#a99e0230f012aef6125ba659f178f198b",
+"classIMP_1_1container_1_1AllBipartitePairContainer.html#ab8f999448973bd717dc19c44b3845278",
+"classIMP_1_1container_1_1InContainerSingletonFilter.html#a68fbe4b0e18b81e11a16e8aeb0901e50",
+"classIMP_1_1container_1_1QuadsConstraint.html",
+"classIMP_1_1core_1_1ChildrenRefiner.html#a742dc731ef07bd773f8db1cdaf714330",
+"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a55cdce4fc454a978c696ea619e0e9c97",
+"classIMP_1_1core_1_1MCCGSampler.html#a029af2b037f814322fbac56bf6626085",
+"classIMP_1_1core_1_1PairRestraint.html#a30451da5a8a91cc076b8cdd92d59862d",
+"classIMP_1_1core_1_1SphereDistancePairScore.html#a6d0f9ad42ae7eabe3a7566cef4b44380",
+"classIMP_1_1core_1_1XYZR.html#aa301c5a743c45801291cf6b0e1981331",
+"classIMP_1_1display_1_1SphereGeometry.html#ad668c1db1984c6bfc47dcc74394d6dc3",
+"classIMP_1_1domino_1_1ListSubsetFilterTable.html#a43f47a195717a826c88ad066c1553656",
+"classIMP_1_1domino_1_1XYZStates.html#ad7567641498035edf1e6b34ec1af2994",
+"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a87bc26efc426f5621fb1b703e50289ca",
+"classIMP_1_1em2d_1_1RelativePositionMover.html",
+"classIMP_1_1em_1_1DensityHeader.html#aceade20863282c4ee23068edfb3571ce",
+"classIMP_1_1em_1_1ImageHeader.html#aa258ac2876aec3c4f19ddfc24420c37e",
+"classIMP_1_1example_1_1ExampleSubsetFilterTable.html#aadb3bc766069259011cbeb54989a40d8",
+"classIMP_1_1isd_1_1GaussianProcessInterpolation.html#a1f7c2c2fdd54fe6cca838691ffc65fe8",
+"classIMP_1_1isd_1_1MultivariateFNormalSufficient.html#ac469de1c0617786175c5ad823f2e2011",
+"classIMP_1_1isd_1_1vonMisesKappaJeffreysRestraint.html#a69c0b213ef8e9ca483f36243c1bd4826",
+"classIMP_1_1kernel_1_1PairPredicate.html#a6f6aeb965bba69c8d9d457c9b7703586",
+"classIMP_1_1kernel_1_1ScoringFunction.html#abd305fcab8433f621d5d038daac0fe70",
+"classIMP_1_1kinematics_1_1ProteinKinematics.html#a158ecc1761e6b1129cfcce34a7625a03",
+"classIMP_1_1multifit_1_1ComplementarityRestraint.html#a27d2804cdd56909b2588535dbd00f095",
+"classIMP_1_1multifit_1_1GeometricHash.html#acb372a29b472a63cd4cba9d3acba9236",
+"classIMP_1_1pmi_1_1CompositeRestraint.html#ad71807d411a54d7a350e1ab62e647c2e",
+"classIMP_1_1saxs_1_1Profile.html#a13a4a73f29bf1da5ed7116eaf22df287",
+"classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html#a65a5b49353be80013bbe86b5b52d952c",
+"core_2ConjugateGradients_8h_source.html",
+"doxygen__macros_8h_source.html",
+"factory_index.html#factory_index_isd",
+"hierarchical__clustering_8h.html#a38a0a5277fb9783dee2f808a24789e88",
+"kernel_2ScoreAccumulator_8h.html#a97dfb0f2aa739b208ffc57bb9b30b61e",
+"kernel_2doxygen_8h.html#ac49c17678e392533e2f6c5927f6eddab",
+"multifit_2RadiusOfGyrationRestraint_8h.html",
+"pair__predicates_8h_source.html",
+"saxs_8h_source.html",
+"structIMP_1_1em_1_1SpiderHeader.html#adcbf89c89216812b3bf0513b37a34724",
+"vonMisesKappaConjugateRestraint_8h_source.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
