@@ -1,5 +1,10 @@
 var NAVTREEINDEX10 =
 {
+"classIMP_1_1atom_1_1BackbonePDBSelector.html#aac44df734c94bf99290149aa244ce0e7":[18,0,0,1,8,4],
+"classIMP_1_1atom_1_1BackbonePDBSelector.html#ab5050b8b5a8a849bc126b00dbcc52d89":[18,0,0,1,8,1],
+"classIMP_1_1atom_1_1BackbonePDBSelector.html#acdb7ebbb1983ee1b77391388e578e8b3":[18,0,0,1,8,0],
+"classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html":[18,0,0,1,9],
+"classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html#a38032436be31d8e80ae7add23ff5db84":[18,0,0,1,9,3],
 "classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html#a4f54ff8eff2631ef67314e3a14475023":[18,0,0,1,9,6],
 "classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html#a5252e97cb650781daa694149871bacad":[18,0,0,1,9,5],
 "classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html#a58367c395f29b13fbfbef4942a69848d":[18,0,0,1,9,10],
@@ -244,10 +249,5 @@ var NAVTREEINDEX10 =
 "classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#a91fff9329d2a36aa42719d443fb5fc35":[18,0,0,1,37,10],
 "classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#a9347ca0463be92c325e6a102f1a55c91":[18,0,0,1,37,2],
 "classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#a9c11526eb9e38b90ab61daa0e6541c26":[18,0,0,1,37,0],
-"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aa49da93fba681223e0eafdc46abb837b":[18,0,0,1,37,25],
-"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aa4f8390a6d5efc7d3a94689490a32808":[18,0,0,1,37,14],
-"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aad7ed56d6b1421d1ee7fdd526e546533":[18,0,0,1,37,6],
-"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aadf17703a67c4701119d2ac558bbbe78":[18,0,0,1,37,27],
-"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#abcc6de2e570fe4614c85968cb7c6f336":[18,0,0,1,37,26],
-"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#acde893f7ad484a981e0e42fbc732f50e":[18,0,0,1,37,22]
+"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aa49da93fba681223e0eafdc46abb837b":[18,0,0,1,37,25]
 };
