@@ -1,5 +1,10 @@
 var NAVTREEINDEX11 =
 {
+"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aa4f8390a6d5efc7d3a94689490a32808":[18,0,0,1,37,14],
+"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aad7ed56d6b1421d1ee7fdd526e546533":[18,0,0,1,37,6],
+"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#aadf17703a67c4701119d2ac558bbbe78":[18,0,0,1,37,27],
+"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#abcc6de2e570fe4614c85968cb7c6f336":[18,0,0,1,37,26],
+"classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#acde893f7ad484a981e0e42fbc732f50e":[18,0,0,1,37,22],
 "classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#ad610c4fa66857daaad66e9ab60c548c1":[18,0,0,1,37,15],
 "classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#add4b79ec748e743f8c1517428af553a6":[18,0,0,1,37,8],
 "classIMP_1_1atom_1_1CHARMMResidueTopologyBase.html#ade44e2c67bf8499b944f2574db441373":[18,0,0,1,37,13],
@@ -244,10 +249,5 @@ var NAVTREEINDEX11 =
 "classIMP_1_1atom_1_1ForceFieldParameters.html#acc61a54cee5f3f8746ee722c8611c357":[18,0,0,1,52,5],
 "classIMP_1_1atom_1_1ForceFieldParameters.html#ad37b61f76545a6e4e6aa67783bfe7f1b":[18,0,0,1,52,7],
 "classIMP_1_1atom_1_1ForceFieldParameters.html#ad67773ba35b3821764e6d8f4e56220e1":[18,0,0,1,52,1],
-"classIMP_1_1atom_1_1ForceFieldParameters.html#ae714757e4ed7bd9359ded45ca83e6e14":[18,0,0,1,52,3],
-"classIMP_1_1atom_1_1ForceFieldParameters.html#afc93d5738add08b79a76395b1afb861b":[18,0,0,1,52,16],
-"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html":[18,0,0,1,52,0],
-"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#a23a3cef96fb2868431d501bb9811df0a":[18,0,0,1,52,0,0],
-"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#a30c9a3f0c884598004d924380d49877f":[18,0,0,1,52,0,2],
-"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#a84126eb37dd1486adb600d0e6ea8a0a5":[18,0,0,1,52,0,1]
+"classIMP_1_1atom_1_1ForceFieldParameters.html#ae714757e4ed7bd9359ded45ca83e6e14":[18,0,0,1,52,3]
 };
