@@ -1,5 +1,10 @@
 var NAVTREEINDEX12 =
 {
+"classIMP_1_1atom_1_1ForceFieldParameters.html#afc93d5738add08b79a76395b1afb861b":[18,0,0,1,52,16],
+"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html":[18,0,0,1,52,0],
+"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#a23a3cef96fb2868431d501bb9811df0a":[18,0,0,1,52,0,0],
+"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#a30c9a3f0c884598004d924380d49877f":[18,0,0,1,52,0,2],
+"classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#a84126eb37dd1486adb600d0e6ea8a0a5":[18,0,0,1,52,0,1],
 "classIMP_1_1atom_1_1ForceFieldParameters_1_1Bond.html#aa15d0d9450dc2754e6482ed960d0c03f":[18,0,0,1,52,0,3],
 "classIMP_1_1atom_1_1ForceSwitch.html":[18,0,0,1,53],
 "classIMP_1_1atom_1_1ForceSwitch.html#a1f824089f73b4e99193ee6b6c51a4aa8":[18,0,0,1,53,2],
@@ -244,10 +249,5 @@ var NAVTREEINDEX12 =
 "classIMP_1_1atom_1_1RemoveTranslationOptimizerState.html#a6437e17c7506f0a748cbe7d491d1b6f1":[18,0,0,1,80,1],
 "classIMP_1_1atom_1_1Representation.html":[18,0,0,1,81],
 "classIMP_1_1atom_1_1Representation.html#a0da3ce7956ea0ac0247bf12a288fddc8":[18,0,0,1,81,1],
-"classIMP_1_1atom_1_1Representation.html#a1b96c33fc98250a2d260e1c957dcb89c":[18,0,0,1,81,8],
-"classIMP_1_1atom_1_1Representation.html#a3086e40c0518364751d0fe8098b07335":[18,0,0,1,81,12],
-"classIMP_1_1atom_1_1Representation.html#a3685030eb111545a64b35843fe30f315":[18,0,0,1,81,11],
-"classIMP_1_1atom_1_1Representation.html#a488edf3e0a1372740e8898b7391a0dd3":[18,0,0,1,81,9],
-"classIMP_1_1atom_1_1Representation.html#a5269fcb7050dd14fe6e89c4eed33381f":[18,0,0,1,81,5],
-"classIMP_1_1atom_1_1Representation.html#a6432fe14f4dddc96cd575d0cc2020ab9":[18,0,0,1,81,10]
+"classIMP_1_1atom_1_1Representation.html#a1b96c33fc98250a2d260e1c957dcb89c":[18,0,0,1,81,8]
 };
