@@ -1,5 +1,10 @@
 var NAVTREEINDEX17 =
 {
+"classIMP_1_1container_1_1QuadsConstraint.html":[18,0,0,6,48],
+"classIMP_1_1container_1_1QuadsConstraint.html#a20864d6bc38c8ae7978e370eb1048d9e":[18,0,0,6,48,5],
+"classIMP_1_1container_1_1QuadsConstraint.html#a50fc23ecb4a51c573f460a932ca6a79c":[18,0,0,6,48,1],
+"classIMP_1_1container_1_1QuadsConstraint.html#a5312ce739098b750bca0549a24b3fdcb":[18,0,0,6,48,3],
+"classIMP_1_1container_1_1QuadsConstraint.html#a68d3b6b4914f7ef0e19af43a7ab614c5":[18,0,0,6,48,6],
 "classIMP_1_1container_1_1QuadsConstraint.html#aae8c74b15bc4e074dc28d54e5dd22b7e":[18,0,0,6,48,2],
 "classIMP_1_1container_1_1QuadsConstraint.html#ab1b6c5d14b15b38461188e72121395af":[18,0,0,6,48,4],
 "classIMP_1_1container_1_1QuadsConstraint.html#ab85f6351f804f88bf4e9354890e4def0":[18,0,0,6,48,0],
@@ -244,10 +249,5 @@ var NAVTREEINDEX17 =
 "classIMP_1_1core_1_1ChildrenRefiner.html#a003bba2711e3fbc7c5c3213ae4b44216":[17,1,1,5],
 "classIMP_1_1core_1_1ChildrenRefiner.html#a1bdf4b14c911ebe75f511a0f2c765be7":[17,1,1,6],
 "classIMP_1_1core_1_1ChildrenRefiner.html#a42d2912e2491f7bf7fac03c7eaa61602":[17,1,1,2],
-"classIMP_1_1core_1_1ChildrenRefiner.html#a46d4648ed609952a2a0f8dac017daaca":[17,1,1,3],
-"classIMP_1_1core_1_1ChildrenRefiner.html#a742dc731ef07bd773f8db1cdaf714330":[17,1,1,4],
-"classIMP_1_1core_1_1ChildrenRefiner.html#ab63470be709553245ce9b29bf52c352d":[17,1,1,1],
-"classIMP_1_1core_1_1ChildrenRefiner.html#ac93f559610e5324ee059430e86e4b7c0":[17,1,1,0],
-"classIMP_1_1core_1_1ClosePairsFinder.html":[18,0,0,7,14],
-"classIMP_1_1core_1_1ClosePairsFinder.html#a03dce852dc0b4a9bb0b173f73b118982":[18,0,0,7,14,21]
+"classIMP_1_1core_1_1ChildrenRefiner.html#a46d4648ed609952a2a0f8dac017daaca":[17,1,1,3]
 };
