@@ -1,5 +1,10 @@
 var NAVTREEINDEX18 =
 {
+"classIMP_1_1core_1_1ChildrenRefiner.html#a742dc731ef07bd773f8db1cdaf714330":[17,1,1,4],
+"classIMP_1_1core_1_1ChildrenRefiner.html#ab63470be709553245ce9b29bf52c352d":[17,1,1,1],
+"classIMP_1_1core_1_1ChildrenRefiner.html#ac93f559610e5324ee059430e86e4b7c0":[17,1,1,0],
+"classIMP_1_1core_1_1ClosePairsFinder.html":[18,0,0,7,14],
+"classIMP_1_1core_1_1ClosePairsFinder.html#a03dce852dc0b4a9bb0b173f73b118982":[18,0,0,7,14,21],
 "classIMP_1_1core_1_1ClosePairsFinder.html#a260df5bb0b19f08f6a946fed32d9fd44":[18,0,0,7,14,11],
 "classIMP_1_1core_1_1ClosePairsFinder.html#a2c77b5712a6672628bae4d5d676d95eb":[18,0,0,7,14,15],
 "classIMP_1_1core_1_1ClosePairsFinder.html#a400e54f1bb379b89eae615ebd72e18e6":[18,0,0,7,14,4],
@@ -244,10 +249,5 @@ var NAVTREEINDEX18 =
 "classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a28f5af519e636dfbd7dd7b3331825b46":[18,0,0,7,39,9],
 "classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a38eca47937858be077a55d5f25220114":[18,0,0,7,39,1],
 "classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a41926b3428147857ed80c587f8b70e04":[18,0,0,7,39,10],
-"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a4b08eae60b0a2c83c6dea6fb32655b59":[18,0,0,7,39,12],
-"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a55cdce4fc454a978c696ea619e0e9c97":[18,0,0,7,39,18],
-"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a60bb668eadd5a3c54181ff91d64c61cf":[18,0,0,7,39,8],
-"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a8b57ef2ce21ddd177350dad5d0d7af7d":[18,0,0,7,39,13],
-"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#aa4b026833089cd3c2e1202673b7e3074":[18,0,0,7,39,6],
-"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#aa8abf15d5bd6a0e953494d440c9d5cc3":[18,0,0,7,39,2]
+"classIMP_1_1core_1_1ExcludedVolumeRestraint.html#a4b08eae60b0a2c83c6dea6fb32655b59":[18,0,0,7,39,12]
 };
