@@ -1,5 +1,10 @@
 var NAVTREEINDEX22 =
 {
+"classIMP_1_1core_1_1SphereDistancePairScore.html#a6d0f9ad42ae7eabe3a7566cef4b44380":[18,0,0,7,111,1],
+"classIMP_1_1core_1_1SphereDistancePairScore.html#a6e35c99828c2c596a5c3bf4eb3fef0dd":[18,0,0,7,111,0],
+"classIMP_1_1core_1_1SphereDistancePairScore.html#a881bd467dc6898f85c9159de71c640e1":[18,0,0,7,111,5],
+"classIMP_1_1core_1_1SphereDistancePairScore.html#ad013a3679b20db07dc4e2597f0c8ea8f":[18,0,0,7,111,4],
+"classIMP_1_1core_1_1SphereDistancePairScore.html#ae8221b52afc000cf46adbb93f980fd90":[18,0,0,7,111,2],
 "classIMP_1_1core_1_1SphereDistancePairScore.html#af35d96e28844898402854dbb38d58102":[18,0,0,7,111,3],
 "classIMP_1_1core_1_1SphereDistanceToSingletonScore.html":[18,0,0,7,112],
 "classIMP_1_1core_1_1SphereDistanceToSingletonScore.html#a06a7a10aa5c2bcf0f918a59a0fdf2a7d":[18,0,0,7,112,4],
@@ -244,10 +249,5 @@ var NAVTREEINDEX22 =
 "classIMP_1_1core_1_1XYZR.html#a71a927d537713ec2c44d0f5af5510172":[18,0,0,7,136,10],
 "classIMP_1_1core_1_1XYZR.html#a73655826f4e1f9158b004b00b3090537":[18,0,0,7,136,13],
 "classIMP_1_1core_1_1XYZR.html#a7551726c3af6ffe25bdf3962f4776a6c":[18,0,0,7,136,4],
-"classIMP_1_1core_1_1XYZR.html#a84f6a020a85593afe4a01e7c784a6175":[18,0,0,7,136,17],
-"classIMP_1_1core_1_1XYZR.html#aa301c5a743c45801291cf6b0e1981331":[18,0,0,7,136,14],
-"classIMP_1_1core_1_1XYZR.html#abdbf34096e3d265bae65a305e71c3ca6":[18,0,0,7,136,5],
-"classIMP_1_1core_1_1XYZR.html#abea1181840755a6caffe6ab9f4d07fb2":[18,0,0,7,136,11],
-"classIMP_1_1core_1_1XYZR.html#ad0273251cedbcec467af745cc6d1b7d1":[18,0,0,7,136,9],
-"classIMP_1_1core_1_1XYZR.html#adedc98cf7f73a7f29887d37f83066afe":[18,0,0,7,136,16]
+"classIMP_1_1core_1_1XYZR.html#a84f6a020a85593afe4a01e7c784a6175":[18,0,0,7,136,17]
 };
