@@ -1,5 +1,10 @@
 var NAVTREEINDEX26 =
 {
+"classIMP_1_1domino_1_1XYZStates.html#ad7567641498035edf1e6b34ec1af2994":[18,0,0,9,46,8],
+"classIMP_1_1domino_1_1XYZStates.html#ad9339dac5235f6f7431552cc892c9b1c":[18,0,0,9,46,3],
+"classIMP_1_1em2d_1_1AverageDistanceLinkage.html":[18,0,0,11,8],
+"classIMP_1_1em2d_1_1AverageDistanceLinkage.html#a9e4a72284ae366295907143152ca8cb1":[18,0,0,11,8,1],
+"classIMP_1_1em2d_1_1AverageDistanceLinkage.html#ab72135d2cb394f7d64a46271e3346e0d":[18,0,0,11,8,2],
 "classIMP_1_1em2d_1_1AverageDistanceLinkage.html#ad482ade917710e728848f4bc505b0f96":[18,0,0,11,8,0],
 "classIMP_1_1em2d_1_1CenteredMat.html":[18,0,0,11,9],
 "classIMP_1_1em2d_1_1CenteredMat.html#a07080157f83de27fec68e4f2fb607035":[18,0,0,11,9,13],
@@ -244,10 +249,5 @@ var NAVTREEINDEX26 =
 "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a393420c811e388d4b7ce27dc8c52acf8":[18,0,0,11,27,2],
 "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a3dd656c0f71e7189264c6d57aad86aab":[18,0,0,11,27,6],
 "classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a5a9cd9610c937d6f353c5340ffb557e3":[18,0,0,11,27,8],
-"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a7b526d778654e71d5f8fb9a7d2d504bd":[18,0,0,11,27,0],
-"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a87bc26efc426f5621fb1b703e50289ca":[18,0,0,11,27,9],
-"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#abe4ea8ee65e316e0642cfd0dadd2aaaa":[18,0,0,11,27,5],
-"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#ada85593d93e916c209685881c7a4fcd5":[18,0,0,11,27,4],
-"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#aef07c925bde0f482ec77c9854ef56e88":[18,0,0,11,27,3],
-"classIMP_1_1em2d_1_1LessPairBySecond.html":[18,0,0,11,28]
+"classIMP_1_1em2d_1_1JPGImageReaderWriter.html#a7b526d778654e71d5f8fb9a7d2d504bd":[18,0,0,11,27,0]
 };
