@@ -1,5 +1,39 @@
 var NAVTREEINDEX39 =
 {
+"classIMP_1_1multifit_1_1GeometricHash.html#acb372a29b472a63cd4cba9d3acba9236":[18,0,0,22,13,20],
+"classIMP_1_1multifit_1_1GeometricHash.html#ad836b61873521a48bf1a0211f2d139f2":[18,0,0,22,13,30],
+"classIMP_1_1multifit_1_1GeometricHash.html#adb8e5c95a478e0bbe3d809319c83b1b9":[18,0,0,22,13,28],
+"classIMP_1_1multifit_1_1GeometricHash.html#ae31af98ef2aa3538693d4e1274b40448":[18,0,0,22,13,4],
+"classIMP_1_1multifit_1_1GeometricHash.html#af27979d83ab363c4faba107276c9a756":[18,0,0,22,13,25],
+"classIMP_1_1multifit_1_1GeometricHash.html#afe9af3b97de330452c7586379948501d":[18,0,0,22,13,24],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html":[18,0,0,22,14],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#a13a3e1c414e519bedf56aafb73df229c":[18,0,0,22,14,7],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#a641de0dba9b07e1e40de2155d003fa56":[18,0,0,22,14,5],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#a73c82332a104b6529ab35f9f7166c790":[18,0,0,22,14,1],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#a79423abc2b9696cd6ad25e07032a46f7":[18,0,0,22,14,4],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#ac1110a8acc31b297a9585655518de79d":[18,0,0,22,14,3],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#ae22a43002fc2abd6556fdc73b5c6166a":[18,0,0,22,14,2],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#af3df8d98d63354063b425132f74beaca":[18,0,0,22,14,0],
+"classIMP_1_1multifit_1_1MergeTreeBuilder.html#afab14f5c9a72cd77d53336549b6ca154":[18,0,0,22,14,6],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html":[18,0,0,22,15],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a1a53bc783b1a1b1288e84eabcfe32def":[18,0,0,22,15,6],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a24e12e5f652e51ed8958ab688dadb126":[18,0,0,22,15,5],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a58a360bc57999821b28630875b30a4c6":[18,0,0,22,15,13],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a5a049f7aba2c003fdb24b79bcf698987":[18,0,0,22,15,9],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a5a6d2990189fd23771966e9e3f1c4052":[18,0,0,22,15,4],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a5f2ef9d66eb10523c32a2340f45df870":[18,0,0,22,15,11],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a686526609738393520f85c2b7c44761a":[18,0,0,22,15,12],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a6ada36d30eee14e113ebb4ac5b2d294e":[18,0,0,22,15,1],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a6fe03fdb53d58bd209823e474f0e9d1b":[18,0,0,22,15,7],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a718e55ffaf4ee83eac7ef827254f7a5d":[18,0,0,22,15,3],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a9318bd6d1eeac39d29670c8aa3fc3d08":[18,0,0,22,15,10],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#a9907bbba7378306f54613ebceeafdd18":[18,0,0,22,15,2],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#abfe16f182ca11750346b34dd55e0c8af":[18,0,0,22,15,0],
+"classIMP_1_1multifit_1_1ProbabilisticAnchorGraph.html#add5926e503f54bfebe3d3041bfe4a884":[18,0,0,22,15,8],
+"classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html":[18,0,0,22,16],
+"classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html#a09789e0e14348d1860e8bdc6644ad645":[18,0,0,22,16,8],
+"classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html#a22c953d58bc4a59d0e4aa7c818732983":[18,0,0,22,16,16],
+"classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html#a2adc909ac97063c90a2abd5d65421132":[18,0,0,22,16,1],
 "classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html#a312efc0ebb0f02c4b04894dce3398a7c":[18,0,0,22,16,5],
 "classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html#a5611298f4d66c2966344bb6f37783df5":[18,0,0,22,16,0],
 "classIMP_1_1multifit_1_1ProteinsAnchorsSamplingSpace.html#a62510633960ba1f30358d89d2f855594":[18,0,0,22,16,9],
@@ -215,39 +249,5 @@ var NAVTREEINDEX39 =
 "classIMP_1_1pmi_1_1CompositeRestraint.html#a6c707120e88ea22eb52c3aac324aa90f":[18,0,0,25,10,7],
 "classIMP_1_1pmi_1_1CompositeRestraint.html#a86fd8ac36ae90a4728785990c8314cc6":[18,0,0,25,10,4],
 "classIMP_1_1pmi_1_1CompositeRestraint.html#a88ad8bf14f66ca4b66c600b34b6f52f4":[18,0,0,25,10,2],
-"classIMP_1_1pmi_1_1CompositeRestraint.html#ab2e0770c9c69084ec8618157a4fe5641":[18,0,0,25,10,3],
-"classIMP_1_1pmi_1_1CompositeRestraint.html#ad71807d411a54d7a350e1ab62e647c2e":[18,0,0,25,10,5],
-"classIMP_1_1pmi_1_1Resolution.html":[18,0,0,25,11],
-"classIMP_1_1pmi_1_1Resolution.html#a07e0c32c35432d0bd9261f29903b6c9d":[18,0,0,25,11,8],
-"classIMP_1_1pmi_1_1Resolution.html#a0821325704653b8290092c9b04738139":[18,0,0,25,11,7],
-"classIMP_1_1pmi_1_1Resolution.html#a153b210d2d368f6f36ba991200c4b233":[18,0,0,25,11,3],
-"classIMP_1_1pmi_1_1Resolution.html#a25c768819a7d989e82f5bf6f7994fd72":[18,0,0,25,11,0],
-"classIMP_1_1pmi_1_1Resolution.html#a37abede3fa272b3af6ed880929763bcf":[18,0,0,25,11,5],
-"classIMP_1_1pmi_1_1Resolution.html#a43a16d56c78530b261c3a005f690f4b3":[18,0,0,25,11,9],
-"classIMP_1_1pmi_1_1Resolution.html#a53d017260792799bdf2c60253e1a686f":[18,0,0,25,11,1],
-"classIMP_1_1pmi_1_1Resolution.html#a7e51f07b8c7419e1fa6cb7f4803b5acf":[18,0,0,25,11,6],
-"classIMP_1_1pmi_1_1Resolution.html#a9cd80543af2fbd81b630a1ea4384f496":[18,0,0,25,11,10],
-"classIMP_1_1pmi_1_1Resolution.html#aea8e9de929b1c7509b5caeae270b6c12":[18,0,0,25,11,4],
-"classIMP_1_1pmi_1_1Resolution.html#aecc4b8482477f9c7fdea21d9cf56967d":[18,0,0,25,11,2],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html":[18,0,0,25,12],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a04f117e36f0dfd60fd5588389871e70f":[18,0,0,25,12,6],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a07bf22f2814d86f43e0e71a662fd346b":[18,0,0,25,12,0],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a267b52e8144bc91f701c79222ce7e93f":[18,0,0,25,12,3],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a32d02cbc99dd63e10d1f9c5c6c7e2014":[18,0,0,25,12,1],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a6a487487ed4abe3ad43f2cefccebdfd9":[18,0,0,25,12,8],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a851c1eb14fb7b5f3d94634f4c7d73274":[18,0,0,25,12,7],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#aba108bd1ba57cd8982e11e60795b89f1":[18,0,0,25,12,2],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#adf8d33e12762cd33deb0054f2d2a55ba":[18,0,0,25,12,5],
-"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#af25b5cdb73546c0f99cf370def851abe":[18,0,0,25,12,4],
-"classIMP_1_1pmi_1_1Symmetric.html":[18,0,0,25,13],
-"classIMP_1_1pmi_1_1Symmetric.html#a16284c22719fd76f645306c9d05fc3df":[18,0,0,25,13,7],
-"classIMP_1_1pmi_1_1Symmetric.html#a32b3cc3bde7e8004a29b697d7f88c425":[18,0,0,25,13,5],
-"classIMP_1_1pmi_1_1Symmetric.html#a34a69a1ea576c78f43ae74077918b26b":[18,0,0,25,13,10],
-"classIMP_1_1pmi_1_1Symmetric.html#a5953f9bf4ad5f01b8906a33211494ce8":[18,0,0,25,13,1],
-"classIMP_1_1pmi_1_1Symmetric.html#a69e607c3919cd684b5cd35f6b633a362":[18,0,0,25,13,3],
-"classIMP_1_1pmi_1_1Symmetric.html#a8271d81d8ea67b68dfc2a5d6c4ee906f":[18,0,0,25,13,8],
-"classIMP_1_1pmi_1_1Symmetric.html#a989deccba99f30f6c8cf87fa05ff0958":[18,0,0,25,13,4],
-"classIMP_1_1pmi_1_1Symmetric.html#ab893cd58674082efc59b1e20d7aacb21":[18,0,0,25,13,2],
-"classIMP_1_1pmi_1_1Symmetric.html#ac86ca252e344587a7943d01f6a743baf":[18,0,0,25,13,0],
-"classIMP_1_1pmi_1_1Symmetric.html#ad2c0c3a1149235782e99083015010624":[18,0,0,25,13,6]
+"classIMP_1_1pmi_1_1CompositeRestraint.html#ab2e0770c9c69084ec8618157a4fe5641":[18,0,0,25,10,3]
 };
