@@ -1,5 +1,39 @@
 var NAVTREEINDEX40 =
 {
+"classIMP_1_1pmi_1_1CompositeRestraint.html#ad71807d411a54d7a350e1ab62e647c2e":[18,0,0,25,10,5],
+"classIMP_1_1pmi_1_1Resolution.html":[18,0,0,25,11],
+"classIMP_1_1pmi_1_1Resolution.html#a07e0c32c35432d0bd9261f29903b6c9d":[18,0,0,25,11,8],
+"classIMP_1_1pmi_1_1Resolution.html#a0821325704653b8290092c9b04738139":[18,0,0,25,11,7],
+"classIMP_1_1pmi_1_1Resolution.html#a153b210d2d368f6f36ba991200c4b233":[18,0,0,25,11,3],
+"classIMP_1_1pmi_1_1Resolution.html#a25c768819a7d989e82f5bf6f7994fd72":[18,0,0,25,11,0],
+"classIMP_1_1pmi_1_1Resolution.html#a37abede3fa272b3af6ed880929763bcf":[18,0,0,25,11,5],
+"classIMP_1_1pmi_1_1Resolution.html#a43a16d56c78530b261c3a005f690f4b3":[18,0,0,25,11,9],
+"classIMP_1_1pmi_1_1Resolution.html#a53d017260792799bdf2c60253e1a686f":[18,0,0,25,11,1],
+"classIMP_1_1pmi_1_1Resolution.html#a7e51f07b8c7419e1fa6cb7f4803b5acf":[18,0,0,25,11,6],
+"classIMP_1_1pmi_1_1Resolution.html#a9cd80543af2fbd81b630a1ea4384f496":[18,0,0,25,11,10],
+"classIMP_1_1pmi_1_1Resolution.html#aea8e9de929b1c7509b5caeae270b6c12":[18,0,0,25,11,4],
+"classIMP_1_1pmi_1_1Resolution.html#aecc4b8482477f9c7fdea21d9cf56967d":[18,0,0,25,11,2],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html":[18,0,0,25,12],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a04f117e36f0dfd60fd5588389871e70f":[18,0,0,25,12,6],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a07bf22f2814d86f43e0e71a662fd346b":[18,0,0,25,12,0],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a267b52e8144bc91f701c79222ce7e93f":[18,0,0,25,12,3],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a32d02cbc99dd63e10d1f9c5c6c7e2014":[18,0,0,25,12,1],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a6a487487ed4abe3ad43f2cefccebdfd9":[18,0,0,25,12,8],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#a851c1eb14fb7b5f3d94634f4c7d73274":[18,0,0,25,12,7],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#aba108bd1ba57cd8982e11e60795b89f1":[18,0,0,25,12,2],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#adf8d33e12762cd33deb0054f2d2a55ba":[18,0,0,25,12,5],
+"classIMP_1_1pmi_1_1SigmoidRestraintSphere.html#af25b5cdb73546c0f99cf370def851abe":[18,0,0,25,12,4],
+"classIMP_1_1pmi_1_1Symmetric.html":[18,0,0,25,13],
+"classIMP_1_1pmi_1_1Symmetric.html#a16284c22719fd76f645306c9d05fc3df":[18,0,0,25,13,7],
+"classIMP_1_1pmi_1_1Symmetric.html#a32b3cc3bde7e8004a29b697d7f88c425":[18,0,0,25,13,5],
+"classIMP_1_1pmi_1_1Symmetric.html#a34a69a1ea576c78f43ae74077918b26b":[18,0,0,25,13,10],
+"classIMP_1_1pmi_1_1Symmetric.html#a5953f9bf4ad5f01b8906a33211494ce8":[18,0,0,25,13,1],
+"classIMP_1_1pmi_1_1Symmetric.html#a69e607c3919cd684b5cd35f6b633a362":[18,0,0,25,13,3],
+"classIMP_1_1pmi_1_1Symmetric.html#a8271d81d8ea67b68dfc2a5d6c4ee906f":[18,0,0,25,13,8],
+"classIMP_1_1pmi_1_1Symmetric.html#a989deccba99f30f6c8cf87fa05ff0958":[18,0,0,25,13,4],
+"classIMP_1_1pmi_1_1Symmetric.html#ab893cd58674082efc59b1e20d7aacb21":[18,0,0,25,13,2],
+"classIMP_1_1pmi_1_1Symmetric.html#ac86ca252e344587a7943d01f6a743baf":[18,0,0,25,13,0],
+"classIMP_1_1pmi_1_1Symmetric.html#ad2c0c3a1149235782e99083015010624":[18,0,0,25,13,6],
 "classIMP_1_1pmi_1_1Symmetric.html#ad525fd60aa8680a457e23397c2476eb1":[18,0,0,25,13,9],
 "classIMP_1_1pmi_1_1TransformMover.html":[18,0,0,25,14],
 "classIMP_1_1pmi_1_1TransformMover.html#a14f312b3fc216dbb61df8d62f184f07a":[18,0,0,25,14,10],
@@ -18,9 +52,9 @@ var NAVTREEINDEX40 =
 "classIMP_1_1pmi_1_1TransformMover.html#aefe0b82a7ae0423df354b3fcfc5242a9":[18,0,0,25,14,6],
 "classIMP_1_1pmi_1_1Uncertainty.html":[18,0,0,25,15],
 "classIMP_1_1pmi_1_1Uncertainty.html#a1e6736bc8ecbb44e72152ea1017b4b79":[18,0,0,25,15,3],
+"classIMP_1_1pmi_1_1Uncertainty.html#a21ccda1492e13207b73ec855865f45a5":[18,0,0,25,15,7],
 "classIMP_1_1pmi_1_1Uncertainty.html#a2cf9d32996a6392b84c872be293b4227":[18,0,0,25,15,0],
 "classIMP_1_1pmi_1_1Uncertainty.html#a7b0f0f5305ad5cd33c61aed9d6609e78":[18,0,0,25,15,6],
-"classIMP_1_1pmi_1_1Uncertainty.html#a8a0655bc1192eb3373bde160a98f95cf":[18,0,0,25,15,7],
 "classIMP_1_1pmi_1_1Uncertainty.html#a91990017cd3dac707c5229bbfbf6b4a9":[18,0,0,25,15,4],
 "classIMP_1_1pmi_1_1Uncertainty.html#ab9139b4882cf1867b9759f068512e843":[18,0,0,25,15,9],
 "classIMP_1_1pmi_1_1Uncertainty.html#ad7bd7fd5c725f6102b50900eef8bbb57":[18,0,0,25,15,1],
@@ -32,9 +66,17 @@ var NAVTREEINDEX40 =
 "classIMP_1_1pmi_1_1analysis_1_1Clustering.html":[18,0,0,25,0,1],
 "classIMP_1_1pmi_1_1analysis_1_1Clustering.html#a369f90b9ea1080a77418ebaf77ef3488":[18,0,0,25,0,1,0],
 "classIMP_1_1pmi_1_1analysis_1_1Clustering.html#aca26c1111a9c6c1b3119d8c8f5899a15":[18,0,0,25,0,1,1],
-"classIMP_1_1pmi_1_1analysis_1_1GetModelDensity.html":[18,0,0,25,0,2],
-"classIMP_1_1pmi_1_1analysis_1_1GetModelDensity.html#a63456c01136b8835c5a7af02d062df9d":[18,0,0,25,0,2,1],
-"classIMP_1_1pmi_1_1analysis_1_1GetModelDensity.html#a7c170ecf5e488d1563829408641a45e6":[18,0,0,25,0,2,0],
+"classIMP_1_1pmi_1_1analysis_1_1CrossLinkTable.html":[18,0,0,25,0,2],
+"classIMP_1_1pmi_1_1analysis_1_1GetModelDensity.html":[18,0,0,25,0,3],
+"classIMP_1_1pmi_1_1analysis_1_1GetModelDensity.html#a63456c01136b8835c5a7af02d062df9d":[18,0,0,25,0,3,1],
+"classIMP_1_1pmi_1_1analysis_1_1GetModelDensity.html#a7c170ecf5e488d1563829408641a45e6":[18,0,0,25,0,3,0],
+"classIMP_1_1pmi_1_1analysis_1_1Precision.html":[18,0,0,25,0,4],
+"classIMP_1_1pmi_1_1analysis_1_1Precision.html#a40f1366a70bca2ceebbefb10275da7f5":[18,0,0,25,0,4,0],
+"classIMP_1_1pmi_1_1analysis_1_1Precision.html#a42adb7d41ada68bc17e2c017626ae0dd":[18,0,0,25,0,4,1],
+"classIMP_1_1pmi_1_1analysis_1_1Precision.html#a94f101aa2ca5d4af5d1a08504203f743":[18,0,0,25,0,4,5],
+"classIMP_1_1pmi_1_1analysis_1_1Precision.html#aa54b3225cb83560e31f0bf166c0bbd33":[18,0,0,25,0,4,3],
+"classIMP_1_1pmi_1_1analysis_1_1Precision.html#ab9b10b80769e92fef69bb59f3fcff3c6":[18,0,0,25,0,4,2],
+"classIMP_1_1pmi_1_1analysis_1_1Precision.html#adfa950684736a67a346eb39487851bc9":[18,0,0,25,0,4,4],
 "classIMP_1_1pmi_1_1dof_1_1dof.html":[18,0,0,25,1,0],
 "classIMP_1_1pmi_1_1dof_1_1dof.html#a104bd803aa7aa7c084f1539d02fb218e":[18,0,0,25,1,0,3],
 "classIMP_1_1pmi_1_1dof_1_1dof.html#a20a203cef8617f23c950f47239cb92d2":[18,0,0,25,1,0,2],
@@ -42,8 +84,11 @@ var NAVTREEINDEX40 =
 "classIMP_1_1pmi_1_1dof_1_1dof.html#afca8d319c660bd4d16341395e6b297db":[18,0,0,25,1,0,1],
 "classIMP_1_1pmi_1_1macros_1_1AnalysisReplicaExchange0.html":[18,0,0,25,2,0],
 "classIMP_1_1pmi_1_1macros_1_1AnalysisReplicaExchange0.html#a49eb0d98e1ada0b7d0d35a4338966602":[18,0,0,25,2,0,0],
-"classIMP_1_1pmi_1_1macros_1_1BuildModel1.html":[18,0,0,25,2,1],
-"classIMP_1_1pmi_1_1macros_1_1ReplicaExchange0.html":[18,0,0,25,2,2],
+"classIMP_1_1pmi_1_1macros_1_1AnalysisReplicaExchange0.html#ac0844021a6a9184c7eebd5f5afb97d9b":[18,0,0,25,2,0,1],
+"classIMP_1_1pmi_1_1macros_1_1BuildModel.html":[18,0,0,25,2,1],
+"classIMP_1_1pmi_1_1macros_1_1BuildModel.html#a8cdfb14756b8bdf8e06f017eaf179e8a":[18,0,0,25,2,1,0],
+"classIMP_1_1pmi_1_1macros_1_1BuildModel1.html":[18,0,0,25,2,2],
+"classIMP_1_1pmi_1_1macros_1_1BuildModel1.html#ab86287cbbf709706c9b89f47f6593983":[18,0,0,25,2,2,0],
 "classIMP_1_1pmi_1_1nonmantained_1_1CrossLinkMS.html":[18,0,0,25,4,0],
 "classIMP_1_1pmi_1_1output_1_1Output.html":[18,0,0,25,5,0],
 "classIMP_1_1pmi_1_1output_1_1Output.html#a4fd540460df91b5d9cbb1048db1edf58":[18,0,0,25,5,0,0],
@@ -204,50 +249,5 @@ var NAVTREEINDEX40 =
 "classIMP_1_1saxs_1_1Profile.html#a01f78fbf66278238bdb0347197a383ff":[18,0,0,28,7,52],
 "classIMP_1_1saxs_1_1Profile.html#a0294a033abb583bd6e36d9cdc79c4c02":[18,0,0,28,7,36],
 "classIMP_1_1saxs_1_1Profile.html#a05b9ffa15fa27820ae6d173a106d69c6":[18,0,0,28,7,57],
-"classIMP_1_1saxs_1_1Profile.html#a0a1d33df12a2c8468a675327e5d2bb3c":[18,0,0,28,7,9],
-"classIMP_1_1saxs_1_1Profile.html#a13a4a73f29bf1da5ed7116eaf22df287":[18,0,0,28,7,1],
-"classIMP_1_1saxs_1_1Profile.html#a191109db9160b6e5cd4a8e222346b574":[18,0,0,28,7,31],
-"classIMP_1_1saxs_1_1Profile.html#a1b7eb0f489b7d0bc5faff177deb6b0f5":[18,0,0,28,7,69],
-"classIMP_1_1saxs_1_1Profile.html#a1c170e6a2d3867d31fb0a6104093cd33":[18,0,0,28,7,20],
-"classIMP_1_1saxs_1_1Profile.html#a1ca6ab288f7dc2715307e6c18dbb1101":[18,0,0,28,7,59],
-"classIMP_1_1saxs_1_1Profile.html#a206cb946c9bf60b1e23953f4a214f0c0":[18,0,0,28,7,64],
-"classIMP_1_1saxs_1_1Profile.html#a212a0770476e6fb88e397da9ded2b575":[18,0,0,28,7,35],
-"classIMP_1_1saxs_1_1Profile.html#a2468304f26a82e8ccb687616d58e5db1":[18,0,0,28,7,38],
-"classIMP_1_1saxs_1_1Profile.html#a26b9a35d372522576ccc09a227fd8b0a":[18,0,0,28,7,51],
-"classIMP_1_1saxs_1_1Profile.html#a2b78fec7def1651dd146724274d0ea55":[18,0,0,28,7,62],
-"classIMP_1_1saxs_1_1Profile.html#a2bd8791b204014530ae18c90df2bd34b":[18,0,0,28,7,13],
-"classIMP_1_1saxs_1_1Profile.html#a2da7f760b5f7c057cf2856a613c681b9":[18,0,0,28,7,41],
-"classIMP_1_1saxs_1_1Profile.html#a34ed91e024669079bffb1682aa5e2a25":[18,0,0,28,7,15],
-"classIMP_1_1saxs_1_1Profile.html#a38717280bf9fdc2e21bb21649f1bb0a9":[18,0,0,28,7,24],
-"classIMP_1_1saxs_1_1Profile.html#a3f1174dc4a95eb52759b8c327ebc847e":[18,0,0,28,7,47],
-"classIMP_1_1saxs_1_1Profile.html#a4399e983e2635c7fecb2d0e98c8dce05":[18,0,0,28,7,53],
-"classIMP_1_1saxs_1_1Profile.html#a4841bad8ad5a101d521f511590ea7890":[18,0,0,28,7,28],
-"classIMP_1_1saxs_1_1Profile.html#a49f28ac715179d8de02801de3881337e":[18,0,0,28,7,56],
-"classIMP_1_1saxs_1_1Profile.html#a4d705b535cd2f8736c679a326fea542d":[18,0,0,28,7,60],
-"classIMP_1_1saxs_1_1Profile.html#a539ad3784a3f3f14673894df1cfd1fd2":[18,0,0,28,7,22],
-"classIMP_1_1saxs_1_1Profile.html#a53b3b4a871fdc6b866c4e635e0d444c7":[18,0,0,28,7,71],
-"classIMP_1_1saxs_1_1Profile.html#a5ada436966a8f9da3b681e8515ad843e":[18,0,0,28,7,14],
-"classIMP_1_1saxs_1_1Profile.html#a5bde6fd06d4f7d6050d4a15373719c74":[18,0,0,28,7,67],
-"classIMP_1_1saxs_1_1Profile.html#a5d5b4d04927cb80dadc9324acc4770ca":[18,0,0,28,7,6],
-"classIMP_1_1saxs_1_1Profile.html#a65376b467a74a5ac2aeb2cb21b0a5c2a":[18,0,0,28,7,26],
-"classIMP_1_1saxs_1_1Profile.html#a66a17a8754a50ea50f3f2313aed786c0":[18,0,0,28,7,8],
-"classIMP_1_1saxs_1_1Profile.html#a6c1a2c47027a383a34e11186c6686ab2":[18,0,0,28,7,58],
-"classIMP_1_1saxs_1_1Profile.html#a782cce8306c6309453b7954c046f75f8":[18,0,0,28,7,34],
-"classIMP_1_1saxs_1_1Profile.html#a7899931e7a34c5a37a4ef21c62fd90f8":[18,0,0,28,7,12],
-"classIMP_1_1saxs_1_1Profile.html#a79e71251ae5d3759abeaefe1db6e5e41":[18,0,0,28,7,44],
-"classIMP_1_1saxs_1_1Profile.html#a7f235296d8c8d1020740d00043d3d241":[18,0,0,28,7,63],
-"classIMP_1_1saxs_1_1Profile.html#a82536430388b99179eaf494ab3c4a227":[18,0,0,28,7,3],
-"classIMP_1_1saxs_1_1Profile.html#a83d5279ce74b9721145ebd438e7019bf":[18,0,0,28,7,10],
-"classIMP_1_1saxs_1_1Profile.html#a8402d2369a85a45ccfa8247652df29a8":[18,0,0,28,7,29],
-"classIMP_1_1saxs_1_1Profile.html#a88c919ebd971f20181b1fc03c44fd07b":[18,0,0,28,7,7],
-"classIMP_1_1saxs_1_1Profile.html#a8a1d10d7b06c24dbc9cc3b70d7b56a92":[18,0,0,28,7,46],
-"classIMP_1_1saxs_1_1Profile.html#a8f5c1029f924aaeec6b0604021f812f7":[18,0,0,28,7,65],
-"classIMP_1_1saxs_1_1Profile.html#a94860d6bee067b549c09e2aff936bd15":[18,0,0,28,7,68],
-"classIMP_1_1saxs_1_1Profile.html#a952595c21b3905c2669e5b0bee96eb9e":[18,0,0,28,7,17],
-"classIMP_1_1saxs_1_1Profile.html#a98206f86eca618bc32993a74bac9aefc":[18,0,0,28,7,70],
-"classIMP_1_1saxs_1_1Profile.html#a9a356b8f504a66e0ad59bd7055787f39":[18,0,0,28,7,66],
-"classIMP_1_1saxs_1_1Profile.html#a9abe9204416ee2bbf096f85bc0016027":[18,0,0,28,7,23],
-"classIMP_1_1saxs_1_1Profile.html#a9e4dff05aaa4890b675d26f52810296d":[18,0,0,28,7,2],
-"classIMP_1_1saxs_1_1Profile.html#aa02c90dd6eae203c62dce957f3cf0208":[18,0,0,28,7,55],
-"classIMP_1_1saxs_1_1Profile.html#aa5389f623987257bd740c30900274d56":[18,0,0,28,7,16]
+"classIMP_1_1saxs_1_1Profile.html#a0a1d33df12a2c8468a675327e5d2bb3c":[18,0,0,28,7,9]
 };
