@@ -1,63 +1,114 @@
 var NAVTREEINDEX51 =
 {
-"set__map__macros_8h.html#a09b1ac40792f226deb85bd87e5e81a16":[19,0,849,6],
-"set__map__macros_8h.html#a79c1ad9abff21010a06f5f595277b914":[19,0,849,1],
-"set__map__macros_8h.html#ab0e42e3ca9940a6b4f7490ff2f980870":[19,0,849,2],
-"set__map__macros_8h.html#ab39b724b07878d699ffeb834c3f2d114":[19,0,849,4],
-"set__map__macros_8h.html#ad4301f17e9a53e2331f174795b6fc0e4":[19,0,849,7],
-"set__map__macros_8h.html#af693a1eb7b3d05c35381adec43df2738":[19,0,849,0],
-"set__map__macros_8h.html#af97284db956ac1052e72a86b7646852e":[19,0,849,5],
-"set__map__macros_8h.html#afd2d900242895c82522bb327484a29fd":[19,0,849,3],
-"set__map__macros_8h_source.html":[19,0,849],
-"setup_8py_source.html":[19,0,853],
-"setup__analysis_8py_source.html":[19,0,854],
-"shared__functions_8py_source.html":[19,0,855],
-"shortest__segment_8h.html":[19,0,857],
-"shortest__segment_8h.html#a242c09659e380bd7d7c1dbc779863023":[19,0,857,0],
-"shortest__segment_8h.html#afacab5ba739f7028d32cd34be05a10c7":[19,0,857,1],
-"shortest__segment_8h_source.html":[19,0,857],
-"show__particles__as__spheres_8py_source.html":[19,0,858],
-"showable__macros_8h.html":[19,0,860],
-"showable__macros_8h.html#a27c0bf6a79c8f5f5aa9442e692bd5ad3":[19,0,860,1],
-"showable__macros_8h.html#a6439c6afb9e60ec9bc7abe7c5ef044d9":[19,0,860,0],
-"showable__macros_8h_source.html":[19,0,860],
-"simple_8cpp_source.html":[19,0,862],
-"simple_8py_source.html":[19,0,863],
-"simple__links_8h.html":[19,0,864],
-"simple__links_8h_source.html":[19,0,864],
-"simplex_8py_source.html":[19,0,866],
-"simulation_8py_source.html":[19,0,867],
-"singleton__macros_8h.html":[19,0,870],
-"singleton__macros_8h_source.html":[19,0,870],
-"singleton__predicates_8h.html":[19,0,871],
-"singleton__predicates_8h_source.html":[19,0,871],
-"six__particles__optimization_8py_source.html":[19,0,890],
-"slave__handler_8py_source.html":[19,0,891],
-"slavestate_8py_source.html":[19,0,892],
-"smoothing__functions_8h.html":[19,0,894],
-"smoothing__functions_8h_source.html":[19,0,894],
-"solutions__io_8py_source.html":[19,0,898],
-"standard__grids_8h.html":[19,0,909],
-"standard__grids_8h.html#ac4f2f1d8b1c6dce6ed145686aecb927a":[19,0,909,6],
-"standard__grids_8h_source.html":[19,0,909],
+"saxs_8h_source.html":[19,0,825],
+"saxs__config_8h_source.html":[19,0,826],
+"scoped_8h.html":[19,0,829],
+"scoped_8h_source.html":[19,0,829],
+"score_8py_source.html":[19,0,831],
+"score__functor_2DistancePairScore_8h.html":[19,0,298],
+"score__functor_2DistancePairScore_8h_source.html":[19,0,298],
+"score__functor_2HarmonicLowerBound_8h.html":[19,0,449],
+"score__functor_2HarmonicLowerBound_8h_source.html":[19,0,449],
+"score__functor_2HarmonicUpperBound_8h.html":[19,0,451],
+"score__functor_2HarmonicUpperBound_8h_source.html":[19,0,451],
+"score__functor_2Harmonic_8h.html":[19,0,447],
+"score__functor_2Harmonic_8h_source.html":[19,0,447],
+"score__functor_2OpenCubicSpline_8h.html":[19,0,621],
+"score__functor_2OpenCubicSpline_8h_source.html":[19,0,621],
+"score__functor_2____init_____8py_source.html":[19,0,29],
+"score__functor_2__version__check_8py_source.html":[19,0,68],
+"score__functor_8h.html":[19,0,832],
+"score__functor_8h_source.html":[19,0,832],
+"score__functor__config_8h_source.html":[19,0,833],
+"score__protein__with__ligand_8py_source.html":[19,0,834],
+"scores2D_8h.html":[19,0,837],
+"scores2D_8h.html#a119a19c90f9203ad6a923a710146dd6d":[19,0,837,10],
+"scores2D_8h.html#a2debbec9a1cb5c04f498d31311f570ef":[19,0,837,8],
+"scores2D_8h.html#a36ce0f68b0bb199a5c0e0e32ded802a6":[19,0,837,17],
+"scores2D_8h.html#a44fe26f303260f075ccda58b350fe8a0":[19,0,837,18],
+"scores2D_8h.html#a57a725bb5e94995d20b75abe96d9cfbd":[19,0,837,19],
+"scores2D_8h.html#a5b8ff3a60997ddbdb47ac3b8fb7afda2":[19,0,837,7],
+"scores2D_8h.html#a6aa15e3e01020f7803fd8a86f12935cf":[19,0,837,16],
+"scores2D_8h.html#a7329e907366cbe699503e43b479e060c":[19,0,837,11],
+"scores2D_8h.html#a8827086222efc622180b57244b37c2d4":[19,0,837,15],
+"scores2D_8h.html#aa02fe1f289665a57a8d691f5006f23c1":[19,0,837,9],
+"scores2D_8h.html#abbe0c5807a2007f836c84c87b18b0737":[19,0,837,12],
+"scores2D_8h.html#ad612906ea96b2c6f162c97b654309c7f":[19,0,837,20],
+"scores2D_8h.html#af27ca8d587434ae80d5d574bad55ca42":[19,0,837,13],
+"scores2D_8h.html#af8132659abe83c8fa62be49ad1544e48":[19,0,837,14],
+"scores2D_8h_source.html":[19,0,837],
+"scratch_2____init_____8py_source.html":[19,0,30],
+"scratch_2__version__check_8py_source.html":[19,0,69],
+"scratch_8h.html":[19,0,843],
+"scratch_8h_source.html":[19,0,843],
+"scratch__config_8h_source.html":[19,0,844],
+"secondary__structure__reader_8h.html":[19,0,845],
+"secondary__structure__reader_8h.html#a3b8e395cdf044456ec136c147761b0f9":[19,0,845,1],
+"secondary__structure__reader_8h.html#ac376e29826164bc29ba340b438507a35":[19,0,845,0],
+"secondary__structure__reader_8h_source.html":[19,0,845],
+"segment_8py_source.html":[19,0,847],
+"serialPeptideDocker_8py_source.html":[19,0,851],
+"set_8h.html":[19,0,852],
+"set_8h_source.html":[19,0,852],
+"set__map__macros_8h.html":[19,0,853],
+"set__map__macros_8h.html#a09b1ac40792f226deb85bd87e5e81a16":[19,0,853,6],
+"set__map__macros_8h.html#a79c1ad9abff21010a06f5f595277b914":[19,0,853,1],
+"set__map__macros_8h.html#ab0e42e3ca9940a6b4f7490ff2f980870":[19,0,853,2],
+"set__map__macros_8h.html#ab39b724b07878d699ffeb834c3f2d114":[19,0,853,4],
+"set__map__macros_8h.html#ad4301f17e9a53e2331f174795b6fc0e4":[19,0,853,7],
+"set__map__macros_8h.html#af693a1eb7b3d05c35381adec43df2738":[19,0,853,0],
+"set__map__macros_8h.html#af97284db956ac1052e72a86b7646852e":[19,0,853,5],
+"set__map__macros_8h.html#afd2d900242895c82522bb327484a29fd":[19,0,853,3],
+"set__map__macros_8h_source.html":[19,0,853],
+"setup_8py_source.html":[19,0,857],
+"setup__analysis_8py_source.html":[19,0,858],
+"shared__functions_8py_source.html":[19,0,859],
+"shortest__segment_8h.html":[19,0,861],
+"shortest__segment_8h.html#a242c09659e380bd7d7c1dbc779863023":[19,0,861,0],
+"shortest__segment_8h.html#afacab5ba739f7028d32cd34be05a10c7":[19,0,861,1],
+"shortest__segment_8h_source.html":[19,0,861],
+"show__particles__as__spheres_8py_source.html":[19,0,862],
+"showable__macros_8h.html":[19,0,864],
+"showable__macros_8h.html#a27c0bf6a79c8f5f5aa9442e692bd5ad3":[19,0,864,1],
+"showable__macros_8h.html#a6439c6afb9e60ec9bc7abe7c5ef044d9":[19,0,864,0],
+"showable__macros_8h_source.html":[19,0,864],
+"simple_8cpp_source.html":[19,0,866],
+"simple_8py_source.html":[19,0,867],
+"simple__links_8h.html":[19,0,868],
+"simple__links_8h_source.html":[19,0,868],
+"simplex_8py_source.html":[19,0,870],
+"simulation_8py_source.html":[19,0,871],
+"singleton__macros_8h.html":[19,0,874],
+"singleton__macros_8h_source.html":[19,0,874],
+"singleton__predicates_8h.html":[19,0,875],
+"singleton__predicates_8h_source.html":[19,0,875],
+"six__particles__optimization_8py_source.html":[19,0,894],
+"slave__handler_8py_source.html":[19,0,895],
+"slavestate_8py_source.html":[19,0,896],
+"smoothing__functions_8h.html":[19,0,898],
+"smoothing__functions_8h_source.html":[19,0,898],
+"solutions__io_8py_source.html":[19,0,902],
+"standard__grids_8h.html":[19,0,913],
+"standard__grids_8h.html#ac4f2f1d8b1c6dce6ed145686aecb927a":[19,0,913,6],
+"standard__grids_8h_source.html":[19,0,913],
 "statistics_2____init_____8py_source.html":[19,0,31],
 "statistics_2__version__check_8py_source.html":[19,0,70],
-"statistics_2embedding_8h.html":[19,0,341],
-"statistics_2embedding_8h.html#a496bec79a13cb92f56baab011c8108b8":[19,0,341,2],
-"statistics_2embedding_8h.html#a997622c2d243a8c25e09cca6f98e8984":[19,0,341,1],
-"statistics_2embedding_8h_source.html":[19,0,341],
+"statistics_2embedding_8h.html":[19,0,343],
+"statistics_2embedding_8h.html#a496bec79a13cb92f56baab011c8108b8":[19,0,343,2],
+"statistics_2embedding_8h.html#a997622c2d243a8c25e09cca6f98e8984":[19,0,343,1],
+"statistics_2embedding_8h_source.html":[19,0,343],
 "statistics_2kmeans_8py-example.html":[20,98],
-"statistics_2python__only_8h.html":[19,0,717],
-"statistics_2python__only_8h.html#a6f2a5df02a675039a03a695b45947498":[19,0,717,0],
-"statistics_2python__only_8h_source.html":[19,0,717],
-"statistics_2utility_8h.html":[19,0,1003],
-"statistics_2utility_8h.html#a974ae5760db93ab3cf0afced47455a29":[19,0,1003,1],
-"statistics_2utility_8h.html#ac31b5cbb1a3c6722e837341ce0ee872d":[19,0,1003,0],
-"statistics_2utility_8h_source.html":[19,0,1003],
+"statistics_2python__only_8h.html":[19,0,721],
+"statistics_2python__only_8h.html#a6f2a5df02a675039a03a695b45947498":[19,0,721,0],
+"statistics_2python__only_8h_source.html":[19,0,721],
+"statistics_2utility_8h.html":[19,0,1007],
+"statistics_2utility_8h.html#a974ae5760db93ab3cf0afced47455a29":[19,0,1007,1],
+"statistics_2utility_8h.html#ac31b5cbb1a3c6722e837341ce0ee872d":[19,0,1007,0],
+"statistics_2utility_8h_source.html":[19,0,1007],
 "statistics_2write_a_metric_8py-example.html":[20,99],
-"statistics_8h.html":[19,0,915],
-"statistics_8h_source.html":[19,0,915],
-"statistics__config_8h_source.html":[19,0,917],
+"statistics_8h.html":[19,0,919],
+"statistics_8h_source.html":[19,0,919],
+"statistics__config_8h_source.html":[19,0,921],
 "structIMP_1_1algebra_1_1DenseFloatLogGridKD.html":[18,0,0,0,6],
 "structIMP_1_1algebra_1_1DenseFloatLogGridKD.html#a3e211b1b7afa39d5ab23d1321ef7d8d6":[18,0,0,0,6,0],
 "structIMP_1_1algebra_1_1DenseFloatLogGridKD.html#a6a8cda3eaebbb40536f21664427417c0":[18,0,0,0,6,1],
@@ -198,56 +249,5 @@ var NAVTREEINDEX51 =
 "structIMP_1_1em_1_1SpiderHeader.html#ac11ffbd9a376f911955f9b099711851e":[18,0,0,10,24,17],
 "structIMP_1_1em_1_1SpiderHeader.html#acb4e1db99310de293216888c6272a1f1":[18,0,0,10,24,18],
 "structIMP_1_1em_1_1SpiderHeader.html#ad791545f3d22cffe1019389d2ddbe126":[18,0,0,10,24,28],
-"structIMP_1_1em_1_1SpiderHeader.html#ad82e062a5761137c7bdc1d6ee07c692a":[18,0,0,10,24,33],
-"structIMP_1_1em_1_1SpiderHeader.html#adcbf89c89216812b3bf0513b37a34724":[18,0,0,10,24,11],
-"structIMP_1_1em_1_1SpiderHeader.html#adeaf66307b519ed730a809c5af25ce9b":[18,0,0,10,24,1],
-"structIMP_1_1em_1_1SpiderHeader.html#aeaf3610892fc88761fd9facc3dc6dbff":[18,0,0,10,24,48],
-"structIMP_1_1em_1_1SpiderHeader.html#aeb064eb2adf442f60f5f0d8888adb73c":[18,0,0,10,24,29],
-"structIMP_1_1em_1_1SpiderHeader.html#aef126ff140ad85c85391aa56270cc2d9":[18,0,0,10,24,21],
-"structIMP_1_1em_1_1SpiderHeader.html#af0902816af169033cf19f8533b1970cf":[18,0,0,10,24,38],
-"structIMP_1_1em_1_1SpiderHeader.html#af171ef4e76f4baf5e3a11ca14703c7a6":[18,0,0,10,24,44],
-"structIMP_1_1em_1_1SpiderHeader.html#af36873cd7b1add638d0714428fe0a31c":[18,0,0,10,24,9],
-"structIMP_1_1em_1_1SpiderHeader.html#afd56497e8ff6e78af624cf66dc1a8e9c":[18,0,0,10,24,47],
-"structIMP_1_1kernel_1_1EvaluationState.html":[18,0,0,15,8],
-"structIMP_1_1kernel_1_1EvaluationState.html#a091c17b7033e58ac21a3d92bd7ff1275":[18,0,0,15,8,2],
-"structIMP_1_1kernel_1_1EvaluationState.html#a3493c899e1a3843b48135ca901150692":[18,0,0,15,8,3],
-"structIMP_1_1kernel_1_1EvaluationState.html#a757166c8b7eefaddf546a1d13877b76e":[18,0,0,15,8,4],
-"structIMP_1_1kernel_1_1EvaluationState.html#ae784e16276a75ea5105acfeabf2b56ad":[18,0,0,15,8,1],
-"structIMP_1_1kernel_1_1EvaluationState.html#af2e9d7e1f57053f8b2f141dca3649fc5":[18,0,0,15,8,0],
-"structIMP_1_1kernel_1_1FloatIndex.html":[18,0,0,15,9],
-"structIMP_1_1kernel_1_1FloatIndex.html#a405d33b3a9e0c114526ff9d542601a4b":[18,0,0,15,9,3],
-"structIMP_1_1kernel_1_1FloatIndex.html#a48a3d2064d0453a829dd3427eb73a0cf":[18,0,0,15,9,1],
-"structIMP_1_1kernel_1_1FloatIndex.html#a56770d3fcecbcb241dbe0e63ccfc98b8":[18,0,0,15,9,7],
-"structIMP_1_1kernel_1_1FloatIndex.html#a6f0a522f726d169e563eea037635b55a":[18,0,0,15,9,6],
-"structIMP_1_1kernel_1_1FloatIndex.html#a7136f2ccd642d513e5c9d9b626d75b45":[18,0,0,15,9,4],
-"structIMP_1_1kernel_1_1FloatIndex.html#a72bc5f4da6f6d48161de827a5d88c787":[18,0,0,15,9,5],
-"structIMP_1_1kernel_1_1FloatIndex.html#ad8f9165237015497a6edf0eb7956cea3":[18,0,0,15,9,2],
-"structIMP_1_1kernel_1_1FloatIndex.html#afe1ec480b21ee09167ddb62bb66bbb58":[18,0,0,15,9,0],
-"structIMP_1_1score__functor_1_1Score.html":[18,0,0,29,9],
-"structIMP_1_1score__functor_1_1Score.html#a0ab749cde5fec4ef0cb00d54e9b1fbce":[18,0,0,29,9,0],
-"structIMP_1_1score__functor_1_1Score.html#a1d075dc0c7fb64457a2b576ffa19b702":[18,0,0,29,9,2],
-"structIMP_1_1score__functor_1_1Score.html#a83293373db107fea52a942492185360e":[18,0,0,29,9,1],
-"structIMP_1_1score__functor_1_1Score.html#a99e074e95e2f8ed813f5ff2e1a6ff788":[18,0,0,29,9,6],
-"structIMP_1_1score__functor_1_1Score.html#ab72a5e31d7d0200aaa07fa1878956453":[18,0,0,29,9,4],
-"structIMP_1_1score__functor_1_1Score.html#acbe612f554106bb9c194b0f2ba88b6f3":[18,0,0,29,9,3],
-"structIMP_1_1score__functor_1_1Score.html#afbec8ea9920ba06772e738e1514c318a":[18,0,0,29,9,5],
-"structure__from__sequence_8py_source.html":[19,0,920],
-"subproc_8py_source.html":[19,0,921],
-"subset__filters_8h.html":[19,0,923],
-"subset__filters_8h.html#a05103184c9285d610f058410eb611871":[19,0,923,25],
-"subset__filters_8h.html#a11a521b6777d93f6325e79c9cee07307":[19,0,923,20],
-"subset__filters_8h.html#a39e27dd0ea428b8ac3d941a8d3b8bfa7":[19,0,923,23],
-"subset__filters_8h.html#a50a67cd170272b173d57eb8ea7b88a32":[19,0,923,26],
-"subset__filters_8h.html#a56a539606e3fa782cc90fe15d431983d":[19,0,923,24],
-"subset__filters_8h.html#a599b2fe25c9d8d99f3bc7bdf83b92108":[19,0,923,15],
-"subset__filters_8h.html#a5c0826b776fc53950bb69bd7c3c344f9":[19,0,923,21],
-"subset__filters_8h.html#a728da02bc869d7454a50da4e47566894":[19,0,923,13],
-"subset__filters_8h.html#a76f2499d5a25e19ef9fb05156b540066":[19,0,923,18],
-"subset__filters_8h.html#a7f86220c573634d97d3d90dab66a15f7":[19,0,923,14],
-"subset__filters_8h.html#a8daff6b07f92c6314a33b506f0ebd011":[19,0,923,17],
-"subset__filters_8h.html#a943ee07a45cbbf1f42ce379d2bae6f20":[19,0,923,27],
-"subset__filters_8h.html#aacac4b1c12a4e6bed761b1f3ca0f0146":[19,0,923,29],
-"subset__filters_8h.html#ab20a4d3fe7e387e6194fc9a926e74c88":[19,0,923,19],
-"subset__filters_8h.html#ab22eb9131f0836a0a3cecbd8093c2696":[19,0,923,22],
-"subset__filters_8h.html#acecba26d7827eb0b911174ca9645fbd3":[19,0,923,16]
+"structIMP_1_1em_1_1SpiderHeader.html#ad82e062a5761137c7bdc1d6ee07c692a":[18,0,0,10,24,33]
 };
