@@ -1,5 +1,10 @@
 var NAVTREEINDEX8 =
 {
+"classIMP_1_1algebra_1_1DefaultEmbeddingD.html#aa939cc38c61633c05ba8f512671c9922":[18,0,0,0,5,2],
+"classIMP_1_1algebra_1_1DefaultEmbeddingD.html#ae4437a1c4ca95b4abbf58c9531209d02":[18,0,0,0,5,8],
+"classIMP_1_1algebra_1_1DenseGridStorageD.html":[18,0,0,0,8],
+"classIMP_1_1algebra_1_1DenseGridStorageD.html#a039fc1cdca8326d4d49b0f990f95642a":[18,0,0,0,8,4],
+"classIMP_1_1algebra_1_1DenseGridStorageD.html#a0b3d0d256b138dbc152f010a3bd6de5a":[18,0,0,0,8,13],
 "classIMP_1_1algebra_1_1DenseGridStorageD.html#a2db7b83ea46076f7fc8f1952535ccb46":[18,0,0,0,8,1],
 "classIMP_1_1algebra_1_1DenseGridStorageD.html#a4205bb58fce6019dab59da49da398287":[18,0,0,0,8,16],
 "classIMP_1_1algebra_1_1DenseGridStorageD.html#a4245a59c5356d19e70ba8e6953a7bc33":[18,0,0,0,8,21],
@@ -244,10 +249,5 @@ var NAVTREEINDEX8 =
 "classIMP_1_1algebra_1_1Rotation2D.html#af81a15837d618f5193cf977d50efa840":[18,0,0,0,28,4],
 "classIMP_1_1algebra_1_1Rotation3D.html":[18,0,0,0,29],
 "classIMP_1_1algebra_1_1Rotation3D.html#a16a68aa93e72637d2a5e513714dc3a41":[18,0,0,0,29,11],
-"classIMP_1_1algebra_1_1Rotation3D.html#a1f4eed6fc383b00ae8c5430c42190d39":[18,0,0,0,29,13],
-"classIMP_1_1algebra_1_1Rotation3D.html#a245bbd42a3c675e79a9ad216d7b63be4":[18,0,0,0,29,16],
-"classIMP_1_1algebra_1_1Rotation3D.html#a3c5847cf24d860a0029e13a388a6360e":[18,0,0,0,29,10],
-"classIMP_1_1algebra_1_1Rotation3D.html#a59b89ac91698f8806ebc47208ab97e7e":[18,0,0,0,29,4],
-"classIMP_1_1algebra_1_1Rotation3D.html#a5a6cbed7f9663fb5f8e56a17b10f1139":[18,0,0,0,29,15],
-"classIMP_1_1algebra_1_1Rotation3D.html#a64277befc08357d6768b5f8cba5fdf56":[18,0,0,0,29,5]
+"classIMP_1_1algebra_1_1Rotation3D.html#a1f4eed6fc383b00ae8c5430c42190d39":[18,0,0,0,29,13]
 };
