@@ -1,5 +1,10 @@
 var NAVTREEINDEX9 =
 {
+"classIMP_1_1algebra_1_1Rotation3D.html#a245bbd42a3c675e79a9ad216d7b63be4":[18,0,0,0,29,16],
+"classIMP_1_1algebra_1_1Rotation3D.html#a3c5847cf24d860a0029e13a388a6360e":[18,0,0,0,29,10],
+"classIMP_1_1algebra_1_1Rotation3D.html#a59b89ac91698f8806ebc47208ab97e7e":[18,0,0,0,29,4],
+"classIMP_1_1algebra_1_1Rotation3D.html#a5a6cbed7f9663fb5f8e56a17b10f1139":[18,0,0,0,29,15],
+"classIMP_1_1algebra_1_1Rotation3D.html#a64277befc08357d6768b5f8cba5fdf56":[18,0,0,0,29,5],
 "classIMP_1_1algebra_1_1Rotation3D.html#a65b6637966fb8c03f68f0154476dd634":[18,0,0,0,29,6],
 "classIMP_1_1algebra_1_1Rotation3D.html#a6ac672270fcad45eeffb377404553e66":[18,0,0,0,29,2],
 "classIMP_1_1algebra_1_1Rotation3D.html#a6e8cb23dae55da2e45c157f5b0654108":[18,0,0,0,29,8],
@@ -244,10 +249,5 @@ var NAVTREEINDEX9 =
 "classIMP_1_1atom_1_1AtomType.html":[18,0,0,1,7],
 "classIMP_1_1atom_1_1BackbonePDBSelector.html":[18,0,0,1,8],
 "classIMP_1_1atom_1_1BackbonePDBSelector.html#a7458373c30d201d061017fa0d4204538":[18,0,0,1,8,2],
-"classIMP_1_1atom_1_1BackbonePDBSelector.html#a76d8f5558781fde1625a51389ae44aba":[18,0,0,1,8,3],
-"classIMP_1_1atom_1_1BackbonePDBSelector.html#aac44df734c94bf99290149aa244ce0e7":[18,0,0,1,8,4],
-"classIMP_1_1atom_1_1BackbonePDBSelector.html#ab5050b8b5a8a849bc126b00dbcc52d89":[18,0,0,1,8,1],
-"classIMP_1_1atom_1_1BackbonePDBSelector.html#acdb7ebbb1983ee1b77391388e578e8b3":[18,0,0,1,8,0],
-"classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html":[18,0,0,1,9],
-"classIMP_1_1atom_1_1BerendsenThermostatOptimizerState.html#a38032436be31d8e80ae7add23ff5db84":[18,0,0,1,9,3]
+"classIMP_1_1atom_1_1BackbonePDBSelector.html#a76d8f5558781fde1625a51389ae44aba":[18,0,0,1,8,3]
 };
