@@ -10,5 +10,7 @@ var rigid__bodies_8h =
     [ "create_rigid_bodies", "rigid__bodies_8h.html#a142080670d025ed3bcba01dddab39549", null ],
     [ "get_initial_reference_frame", "rigid__bodies_8h.html#a4a6d455367f3db8a6b6d9cbc3302e185", null ],
     [ "get_initial_reference_frame", "rigid__bodies_8h.html#a6c72c4715dfbfd21c4dd054113be7c1c", null ],
+    [ "get_root_rigid_body", "rigid__bodies_8h.html#af9636f52f818df052141f98a829e1eeb", null ],
+    [ "show_rigid_body_hierarchy", "rigid__bodies_8h.html#a2abc47490c92e47767b9fe3b6771efa0", null ],
     [ "transform", "rigid__bodies_8h.html#a4c5298df54cae6b0e4419852390281be", null ]
 ];
\ No newline at end of file
